\name{armaModelling}

\alias{armaModelling}

\alias{fARMA}
\alias{fARMA-class}

\alias{armaSim}
\alias{armaFit}

\alias{predict.fARMA}

\alias{print.fARMA}
\alias{plot.fARMA}
\alias{summary.fARMA}

\alias{fitted.values.fARMA}
\alias{residuals.fARMA}


\title{Integrated ARIMA Time Series Modelling}


\description{

	A collection of simple to use functions to model univariate autoregressive 
	moving average time series processes, including time series simulation, 
	parameter estimation, diagnostic analysis of the fit, and predictions 
	of future values.
	\cr
		
	The function can be called with the following formula arguments:
	
	\tabular{rll}{
		1	\tab 	\code{x ~ ar()} 	    
			\tab  	autoregressive time series processes, \cr
		2	\tab 	\code{x ~ arma()} 	
			\tab  	autregressive moving average processes,\cr
		3	\tab 	\code{x ~ arima()} 	
			\tab  	autoregressive integrated moving average processes, and \cr
		4	\tab 	\code{x ~ fracdiff()}
			\tab  	fractionally integrated ARMA processes. }
	
	For the first and third selection \code{x ~ ar()} or \code{x ~ arima()}
	the function uses the AR and ARIMA modelling as implemented in 
	\R's \code{ts} package, for the second selection \code{x~arma()} 
	the function uses the ARMA modelling implemented in \R's 
	contributed \code{tseries} package, and for the last selection 
	\code{x~fracdiff()} the function uses fractional ARIMA modelling 
	from \R's contributed \code{fracdiff} package. Note that AR, MA,
  	and ARMA processes can all be modelled by the same algorithm
  	specifying the formula \code{x~arima(p,d,q)} in the proper way, 
  	i.e. setting \code{d=0} and choosing the orders of \code{p} and 
  	\code{q} as zero in agreement with the desired model specification.

}
	
	
\note{
	
	There is nothing really new in this package.
	The benefit you will get with this collection is, that all functions 
	have a common argument list with a formula to specify the model 
	and presetted arguments for the specification of the algorithmic 
	method. For users who have already modeled GARCH processes with 
	SPlus, this approach will be quite natural.
	
	On the other hand, the user can still use the underlying 
	functions from the \code{ts}, \code{tseries}, or 
	\code{fracdiff} packages. No function from these packages
	is masked or overwritten.
	
	The output of the \code{predict}, \code{print} and \code{summary}
	methods have all the same style of format with some additional 
	algorithm specific printing. This makes it easier to interpret 
	the results obtained from different algorithms implemented in 
	different functions.
	
}


\usage{
armaSim(model = list(ar=c(0.5, -0.5), d=0, ma=0.1), n = 100, innov = 
	NULL, n.start = 100, start.innov = NULL, rand.gen = rnorm, \dots) 

armaFit(formula = x ~ arima(2, 0, 1), 
	method = c("CSS-ML", "ML", "CSS", "yw", "burg", "ols", "mle"), 
	include.mean = TRUE, fixed = NULL, fracdiff.M = 100, fracdiff.h = -1, 
	title = "", description = "", \dots)

\method{predict}{fARMA}(object, n.ahead = 10, n.back = 50, conf = c(80,95), 
	doplot = TRUE, doprint = TRUE, \dots)
	
\method{print}{fARMA}(x, \dots)
\method{plot}{fARMA}(x, gof.lag, reference.grid = TRUE, col = "steelblue4", \dots)
\method{summary}{fARMA}(object, doplot = TRUE, \dots)

}


\arguments{
 
	\item{col, reference.grid}{
		[plot] - \cr
		a character string to set the plot color, by default 
		\code{"steelblue4"}; and a logical flag, by default \code{TRUE},
		to draw a reference grid on the plot or not.
		} 
	\item{description, title}{
		two character strings, assigning a title and a brief description
		to an \code{"fARMA"} object.
		}
	\item{doplot}{
		[predict][summary] - \cr
	  	is used by the \code{predict} and \code{summary} methods. By default,
	  	this value is set to \code{TRUE} and thus the function calls generate 
	  	beside written also graphical printout.
	    Additional arguments required by underlying functions have 
	    to be passed through the \code{dots} argument.
	  	}	
	\item{doprint}{
		[predict] - \cr
		should intermediate results be printed? Arguments used by the 
		\code{predict} method.
		}
	\item{fixed}{
		[armaFit] - \cr
	    is an optional numeric vector of the same length as the total
	    number of parameters. If supplied, only \code{NA} entries in
	    \code{fixed} will be varied. In this way subset ARMA processes
	    can be modeled. ARIMA modelling supports this option. Thus
	    for estimating parameters of subset ARMA and AR models the 
	    most easiest way is to specify them by the formulas 
	    \code{x~ARIMA(p, 0, q)} and \code{x~ARIMA(p, 0, 0)}, respectively.
	    }
	 \item{formula}{
	 	[armaFit] - \cr
	  	a formula specifying the general structure of the ARMA form. 
	  	Can have one of the forms  
	  	\code{x ~ ar(q)}, 
	  	\code{x ~ arma(p, q)}, 
	  	\code{x ~ arima(p, d, q)}, or
	  	\code{x ~ fracdiff(p, q)}.
	  	\code{x} is the response variable and must appear in the 
	  	formula expression.
	  	In the first case R's function \code{ar} from the \code{ts}
	  	package will be used to estimate the parameters, in the second
	  	case R's function \code{arma} from the \code{tseries} package
	  	will be used, in the third case R's function \code{arima} from 
	  	the \code{ts} package will be used, and in the last case R's
	  	function \code{fracdiff} from the \code{fracdiff} package will
	  	be used. The state space modelling based \code{arima} function
	  	allows also to fit ARMA models using \code{arima(p, d=0, q)}, and
	  	AR models using \code{arima(q, d=0, q=0)}, or pure MA models
	  	using \code{arima(q=0, d=0, p)}. (Exogenous variables are also 
	  	allowed and can be passed through the \code{\dots} argument.)
	  	}
	\item{fracdiff.M, fracdiff.h}{
		two numeric parameter values for the \code{"fracdiff"} 
		estimator. \code{M} is the number of terms in the likelihood 
		approximation. \code{h} is the size of the finite difference 
		interval for numerical derivatives. By default, or if negative, 
		\code{h=min(0.1,eps.5*(1+ abs(cllf)))}, where 
		\code{clff:=log.max.likelihood}, as returned, and 
		\code{eps.5:=sqrt(.Machine$double.neg.eps)}, typically 
		\code{1.05e-8}.
		} 
	\item{gof.lag}{
		[print][plot][summary][predict] - \cr
    	the maximum number of lags for a goodness-of-fit test.
    	}
    \item{include.mean}{
    	[armaFit] - \cr
	  	Should the ARIMA model include a mean term? The default is 
	    \code{TRUE}, note that for differenced series a mean would 
	    not affect the fit nor predictions.
	    }
	\item{innov}{
		[armaSim] - \cr
		is a univariate time series or vector of innovations to produce 
		the series. If not provided, \code{innov} will be generated using 
		the random number generator specified by \code{rand.gen}. 
		Missing values are not allowed. By default the normal
		random number generator will be used.
		}
	\item{method}{
		[armaFit] - \cr
	    denotes the method used to fit the model by a character string.
	    \code{method} must be one of the strings in the default argument.
	    For ARIMA models a valid selection is one of \code{"CSS-ML"}, 
	    \code{"ML"}, \code{"CSS"}, 
	    for ARMA models only one valid selection is possible \code{"CSS"},
	    for AR models a valid selection is one of \code{"yw"}, \code{"burg"}, 
	    \code{"ols"}, \code{"mle"}, and 
	    for FRACDIFF models only one valid selection is possible 
	    \code{"FRACDIFF"}. If no \code{method} argument specified the
	    following default settings are used: \code{"CSS-ML"} for ARIMA,
	    \code{"FRACDIFF"} for FRACDIFF, \code{"CSS"} for ARMA, and
	    \code{"yw"} for AR modelling. 
	    \cr
	    Additional arguments required by the optimization algorithm have 
	    to be passed through the \code{dots} argument.
    	} 
    \item{model}{
    	[armaSim] - \cr
		a list with one (AR), two (ARMA) or three (ARIMA, FRACDIFF) 
		elements . \code{ar} is a numeric vector giving the AR coefficients, 
		\code{d} is an integer value giving the degree of differencing,
		and \code{ma} is a numeric vector giving the MA coefficients.
		Thus the order of the time series process is (F)ARIMA(p, d, q)
		with \code{p=length(ar)} and \code{q=length(ma)}. \code{d} is
		a positive integer for ARIMA models and a numeric value for
		FRACDIFF models. By default an ARIMA(2, 0, 1) model with 
		coefficients \code{ar=c(0.5, -0.5)} and \code{ma=0.1} will be 
		generated.
		}
   	\item{n}{
   		[armaSim] - \cr
	    is the length of the series to be simulated (optional 
	    if \code{innov} is provided). The default value is 100.
	    }
	\item{n.ahead, n.back, conf}{[print][plot][summary][predict] - \cr
		are presetted arguments for the \code{predict} method. \code{n.ahead}
		determines how far ahead forecasts should be evaluated together
		with errors on the confidence intervals given by the argument
		\code{conf}. If a forecast plot is desired, which is the
		default and expressed by \code{doplot=TRUE}, then \code{n.back} 
		sets the number of time steps back displayed in the graph.
		}
	\item{n.start}{
		[armaSim] - \cr
	    gives the number of start-up values discarded when simulating 
	    non-stationary models. The start-up innovations will be generated 
	    by \code{rand.gen} if \code{start.innov} is not provided.
	    } 
  	\item{object}{
  		[summary][predict] - \cr
	    is an object of class \code{fARMA} returned by the fitting function 
	    \code{armaFit} and serves as input for the \code{summary}, and 
	    \code{predict} methods. Some methods allow for additional 
	    arguments.
	    }
	\item{rand.gen}{
		[armaSim] - \cr
	    is the function which is called to generate the innovations. 
	    Usually, \code{rand.gen} will be a random number generator. 
	    Additional arguments required by the random number generator 
	    \code{rand.gen}, usually the location, scale and/or shape 
	    parameter of the underlying distribution function, have to be 
	    passed through the \code{dots} argument.
	    }
	\item{start.innov}{
		[armaSim] - \cr
	    is a univariate time series or vector of innovations to be used 
	    as start up values. Missing values are not allowed.
	    }
	\item{x}{
  		[print][plot] - \cr
	    is an object of class \code{fARMA} returned by the
	    fitting function \code{armaFit} and serves as input for the 
	    \code{predict}, \code{print}, \code{print.summary},
	    and \code{plot} methods. Some methods allow for additional 
	    arguments.
	    }
	\item{\dots}{
	    additional arguments to be passed.
	    }
	    
}


\values{

	\code{armaFit} 
  	\cr
  	returns an S4 object of class \code{"fARMA"}, with the folliwing 
  	slots:

  	\item{call}{
    	the matched function call.
    	}
  	\item{data}{
  		the input data in form of a data.frame.
  		}
  	\item{description}{
  		allows for a brief project description.
  		}
  	\item{fit}{
  		the results as a list returned from the underlying
  		time series model function. 
  		}
  	\item{method}{
    	the selected time series model naming the applied method.
		}
  	\item{formula}{
    	the formula expression describing the model.
    	}
    \item{parameters}{
    	named parameters or coefficients of the fitted model.
    	}
    \item{title}[
    	a title string.}

}
    	    	

\details{
  
	\bold{AR - Auto-Regressive Modelling:}
	\cr\cr
	The argument \code{x ~ar()} calls the underlying functions 
	\code{ar.yw}, \code{ar.burg}, code{\link{ar.ols}} or \code{ar.mle}. 
	For definiteness, the AR models are defined through

  		\deqn{x_t - \mu = a_1(x_{t-1} - \mu) + \cdots +  a_p(x_{t-p} - \mu) + e_t}{\code{(x[t] - m) = a[1]*(x[t-1] - m) + \dots +  a[p]*(x[t-p] - m) + e[t]}}

  	Order selection can be achieved through the comparison of AIC
  	values for different model specifications. However this may be
    problematic, as of the methods here only \code{ar.mle} performs
    true maximum likelihood estimation. The AIC is computed as if 
    the variance estimate were the MLE, omitting the determinant 
    term from the likelihood. Note that this is not the same as the 
    Gaussian likelihood evaluated at the estimated parameter values. 
    With \code{method="yw"} the variance matrix of the innovations is
    computed from the fitted coefficients and the autocovariance of
    \code{x}. \code{method="burg"} allows two methods to estimate the
    innovations variance and hence AIC. Method 1 is to use the update 
    given by the Levinson-Durbin recursion (Brockwell and Davis, 1991), 
    and follows S-PLUS. Method 2 is the mean of the sum of squares of 
    the forward and backward prediction errors (as in Brockwell and Davis, 
    1996). Percival and Walden (1998) discuss both. 
    \cr
    \code{[ts:ar]}
    \cr
    
    
    \bold{ARMA - Auto-Regressive Moving-Average Modelling:}
    \cr\cr   
	The argument \code{x ~ arma()} calls the underlying functions 
	\code{arma} from \R's \code{tseries} package. The following 
	parametrization is used for the ARMA(p,q) model:
  
  		\deqn{y[t] = a[0] + a[1]y[t-1] + \dots + a[p]y[t-p] + b[1]e[t-1] + \dots + b[q]e[t-q] + e[t],}
  
  	where \eqn{a[0]} is set to zero if no mean is included. By using the 
  	argument \code{fitted}, it is possible to fit a parsimonious 
  	subset model by setting arbitrary \eqn{a[i]} and \eqn{b[i]} to zero.
  	The optimization uses \code{\link{optim}} to minimize the conditional
  	sum-of-squared errors, {method="CSS"}. The gradient is computed, 
  	if it is needed, by a finite-difference approximation. Default 
  	initialization is done by fitting a pure high-order AR model 
  	(see \code{\link{ar.ols}}). The estimated residuals are then used 
  	for computing a least squares estimator of the full ARMA model. 
  	\cr
  	\code{[tseries:arma]}
  	\cr
  	 	
 	\bold{ARIMA - Integrated ARMA Modelling:}
 	\cr\cr
    The argument \code{x ~ arima()} calls the underlying function 
    \code{arima} from \R's \code{ts} package. For definiteness, the AR 
    models are defined through

  		\deqn{x_t = a_1x_{t-1} + \cdots + a_px_{t-p} + e_t + b_1e_{t-1} + \dots + b_qe_{t-q}}{\code{x[t] = a[1]x[t-1] + \dots + a[p]x[t-p] + e[t] + b[1]e[t-1] + \dots + b[q]e[t-q]}}

  	and so the MA coefficients differ in sign from those of
  	S-PLUS. Further, if \code{include.mean} is \code{TRUE}, this formula
    applies to \eqn{x-m} rather than \eqn{x}.  For ARIMA models with
    differencing, the differenced series follows a zero-mean ARMA model.
  	\cr
  	The variance matrix of the estimates is found from the Hessian of
  	the log-likelihood, and so may only be a rough guide.
 	\cr
 	Optimization is done by \code{\link{optim}}. It will work
  	best if the columns in \code{xreg} are roughly scaled to zero mean
  	and unit variance, but does attempt to estimate suitable scalings.
   	The exact likelihood is computed via a state-space representation 
   	of the ARIMA process, and the innovations and their variance found 
   	by a Kalman filter. The initialization of the differenced ARMA 
   	process uses stationarity. For a differenced process the 
   	non-stationary components are given a diffuse prior (controlled 
   	by \code{kappa}). Observations which are still controlled by the 
   	diffuse prior (determined by having a Kalman gain of at least 
   	\code{1e4}) are excluded from the likelihood calculations. (This 
   	gives comparable results to \code{\link{arima0}} in the absence
    of missing values, when the observations excluded are precisely those
    dropped by the differencing.)
  	\cr
    Missing values are allowed, and are handled exactly in method \code{"ML"}.
	\cr
    If \code{transform.pars} is true, the optimization is done using an
    alternative parametrization which is a variation on that suggested by
    Jones (1980) and ensures that the model is stationary.  For an AR(p)
    model the parametrization is via the inverse tanh of the partial
    autocorrelations: the same procedure is applied (separately) to the
    AR and seasonal AR terms.  The MA terms are not constrained to be
    invertible during optimization, but they will be converted to
    invertible form after optimization if \code{transform.pars} is true.
    \cr
  	Conditional sum-of-squares is provided mainly for expositional
  	purposes.  This computes the sum of squares of the fitted innovations
  	from observation \code{n.cond} on, (where \code{n.cond} is at least
  	the maximum lag of an AR term), treating all earlier innovations to
  	be zero.  Argument \code{n.cond} can be used to allow comparability
  	between different fits.  The ``part log-likelihood'' is the first
  	term, half the log of the estimated mean square.  Missing values
  	are allowed, but will cause many of the innovations to be missing.
	\cr
  	When regressors are specified, they are orthogonalized prior to
  	fitting unless any of the coefficients is fixed. It can be helpful to
  	roughly scale the regressors to zero mean and unit variance.
  	\cr
    Note from \code{arima}: The functions parse their arguments to the 
    original time series functions available in \R's time series library 
    \code{ts}. 
	\cr
  	The results are likely to be different from S-PLUS's
  	\code{arima.mle}, which computes a conditional likelihood and does
  	not include a mean in the model.  Further, the convention used by
  	\code{arima.mle} reverses the signs of the MA coefficients.
  	\cr
  	\code{[ts:arima]}
	\cr
  	   	
  	\bold{FRACDIFF Modelling:}
  	\cr\cr 	 	
    The argument \code{x ~ fracdiff()} calls the underlying functions from
    \R's \code{fracdiff} package. The estimator calculates the maximum 
    likelihood estimators of the parameters of a fractionally-differenced 
    ARIMA (p,d,q) model, together (if possible) with their estimated 
    covariance and correlation matrices and standard errors, as well 
    as the value of the maximized likelihood. The likelihood is 
    approximated using the fast and accurate method of Haslett and 
    Raftery (1989). Note, the number of AR and MA coefficients should 
    not be too large (say < 10) to avoid degeneracy in the model. 
  	\cr
  	The optimization is carried out in two levels: an outer univariate 
  	unimodal optimization in d over the interval [0,.5], and an inner 
  	nonlinear least-squares optimization in the AR and MA parameters to
  	minimize white noise variance.
  	\cr
  	\code{[fracdiff:fracdiff]}
  
}


\references{

Brockwell, P.J. and Davis, R.A. (1996); 
	\emph{Introduction to Time Series and Forecasting}, 
	Second Edition, Springer, New York. 
	
Durbin, J. and Koopman, S.J. (2001); 
	\emph{Time Series Analysis by State Space Methods},  
	Oxford University Press.
	
Gardner, G, Harvey, A.C., Phillips, G.D.A. (1980); 
	\emph{Algorithm AS154. An algorithm for exact maximum likelihood 
	estimation of autoregressive-moving average models by means of 
	Kalman filtering},
	Applied Statistics, 29, 311--322.
	
Hannan E.J. and Rissanen J. (1982);
  	\emph{Recursive Estimation of Mixed Autoregressive-Moving 
  	Average Order.}
  	Biometrika 69, 81--94. 
  	
Harvey, A.C. (1993); 
	\emph{Time Series Models},
	2nd Edition, Harvester Wheatsheaf, Sections 3.3 and 4.4.

Jones, R.H. (1980); 
	\emph{Maximum likelihood fitting of ARMA models to time
	series with missing observations},
	Technometrics, 20, 389--395.

Percival, D.P. and Walden, A.T. (1998); 
	\emph{Spectral Analysis for Physical Applications.} 
	Cambridge University Press.

Whittle, P. (1963); 
	\emph{On the fitting of multivariate autoregressions
	and the approximate canonical factorization of a spectral 
	matrix.}
	Biometrika 40, 129--134.
	
Haslett J. and Raftery A.E. (1989);
    \emph{Space-time Modelling with Long-memory Dependence: Assessing 
    Ireland's Wind Power Resource (with Discussion)},
	Applied Statistics 38, 1--50.
	
}


\author{

	M. Plummer and B.D. Ripley for \code{ar} functions and code,\cr
	A. Trapletti for \code{arma} functions and code,\cr
	B.D. Ripley for \code{arima} functions and code, \cr
	C. Fraley and F. Leisch for \code{fracdiff} functions and code, and \cr
	D. Wuertz for this \R-port.
	
}


\seealso{
  
	\code{\link{armaStatistics}}, 
	\code{\link{garchModelling}}, 
	\code{\link{randomInnovations}},
  	\code{\link{regressionModelling}}.
  	
}


\examples{
## armaSim/armaFit -
   xmpSeries("\nStart: Simulate an ARMA(2, 1) process > ")
   x = armaSim(model = list(ar = c(0.5, -0.5), ma = 0.1), n = 1000)
   Continue = xmpSeries("Press any key > ")
   # Estimate the parameters:
   fit = armaFit(x ~ arma(2, 1))
   print(fit)
   Continue = xmpSeries("Press any key > ") 
   # Diagnostic Analysis:
   par(mfrow = c(3, 2), cex = 0.7)
   summary(fit)
   Continue = xmpSeries("Press any key > ")
   # 5 Steps ahead Forecasts:
   predict(fit, 5)
     
## armaFit -
   xmpSeries("\nNext: Estimate the parameters > ")
   # Now use the arima fitting method with d=0:
   fit = armaFit(x ~ arima(2, 0, 1))
   print(fit)
   Continue = xmpSeries("Press any key > ") 
   # Diagnostic Analysis:
   par(mfrow = c(3, 2), cex = 0.7)
   summary(fit)
   Continue = xmpSeries("Press any key > ") 
   # 5 Step ahead Forecasts:
   predict(fit, n.ahead = 5)
}


\keyword{models}


\eof
\name{armaStatistics}

\alias{armaStatistics}

\alias{armaRoots}
\alias{armaTrueacf}

\title{Statisitcs of the True ARMA Process}


\description{

    A collection of functions for the analysis of the true ARMA
    process. The first investigates the characteristic polynomial
    and the second the true autocorrelation function.
    \cr
    
    The functions are:
		
	\tabular{rll}{
		1	\tab 	\code{armaRoots}	 
			\tab  	Roots of the characteristic ARMA polynomial, \cr
    	2	\tab 	\code{armaTrueacf}
    		\tab  	True autocorrelation function of an ARMA process. }

}


\usage{
armaRoots(coefficients, n.plot = 400, digits = 4, \dots) 
armaTrueacf(model, lag.max = 20, type = "correlation", doplot = TRUE) 
}


\arguments{

  	\item{coefficients}{	
		a numeric vector with the coefficients of the 
		characterisitic polynomial.
		}
  	\item{digits}{	
		output precision, an integer value.
		}
	\item{doplot}{
		a logical. Should a plot be displayed?
		}
	\item{lag.max}{
		 maximum number of lags at which to calculate the acf or 
		 pacf, an integer value by default 20.
		 }
	\item{model}{
		a specification of the ARMA model with two elements:
		\code{model$ar} is the vector of the AR coefficients, and 
		\code{model$ma} is the vector of the MA coefficients.
		}
	\item{n.plot}{	
		the number of data point to plot the unit circle;
		an integer value.
		}
  	\item{type}{
		a character string, "correlation" to compute the true 
		autocorrelation function, "partial" to compute the true
		partial autocorrelation function, or "both" if both
		functions are desired. The start of one of the strings 
		will suffice.
		} 
	\item{\dots}{
		arguments past to the plot function.
		} 		
	
}


\value{
	
	\code{armaRoots} 
	\cr
	returns a three column data frame with the real, the imaginary part 
	and the radius of the roots. The number of rows corresponds
	to the coefficients.
	
	\code{armaTrueacf}
	\cr
	returns a two column data frame with the lag and the correlation 
	function. 
	
}


\author{

	B.D. Ripley for the underlying \code{ARMAacf} function, \cr
	Diethelm Wuertz for this \R-port.
	
}


\seealso{
  
	\code{\link{armaModelling}}.
	
}


\examples{
## armaRoots -
   xmpSeries("\nStart: Roots of the Characteristic Polynomial > ")
   # Calculate and plot the  of an ARMA process:
   par(mfrow = c(2, 2), cex = 0.7)
   coefficients = c(-0.5, 0.9, -0.1, -0.5)
   armaRoots(coefficients)
   
## armaTrueacf -
   xmpSeries("\nNext: True ACF of an ARMA Process > ")
   model = list(ar = c(0.3, +0.3), ma = 0.1)
   armaTrueacf(model)
   model = list(ar = c(0.3, -0.3), ma = 0.1)
   armaTrueacf(model)
}


\keyword{models}


\eof
\name{garchModelling}

\alias{garchModelling}

\alias{fGARCH}
\alias{fAPARCH}

\alias{garchSim}
\alias{garchFit}
\alias{aparchSim}
\alias{aparchFit}

\alias{predict.fGARCH}
\alias{print.fGARCH}
\alias{summary.fGARCH}
\alias{print.summary.fGARCH}
\alias{plot.fGARCH}
\alias{fitted.values.fGARCH}
\alias{residuals.fGARCH}

\alias{predict.fAPARCH}
\alias{print.fAPARCH}
\alias{summary.fAPARCH}
\alias{print.summary.fAPARCH}
\alias{plot.fAPARCH}
\alias{fitted.values.fAPARCH}
\alias{residuals.fAPARCH}


\title{Univariate GARCH Time Series Modelling}


\description{

	Functions to simulate artificial ARCH time series processes, 
	to fit the parameters of univariate time series to ARCH models, 
	to perform a diagnostic analysis of the fit, and to predict 
	future values of the time series.
	
	The family of GARCH time series models includes the following 
	processes:
	
	\tabular{rll}{
		1	\tab 	\code{garch} 
			\tab  	generalized AR conditional heteroskedastic models, \cr
		2	\tab 	\code{aparch} 
			\tab  	asymmetretic power ARCH models. }

	\bold{Note:} This collection is currently under a complete
	reconstruction. It will come back soon allowing for general
	ARMA-GARCH modelling and forecasting, including ARMA 
	specifiations for the mean and GARCH/APARCH specifications 
	for the variance. 

}


\usage{
garchSim(model = list(omega = 1e-6, alpha = 0.1, beta = 0.8, 
	mu = 0), n = 100, innov = NULL, n.start = 100, 
	start.innov = NULL, rand.gen = rnorm, \dots)
garchFit(x, order = c(1, 1),  \dots)

\method{print}{fGARCH}(x, \dots)
\method{summary}{fGARCH}(object, \dots)
\method{print.summary}{fGARCH}(x, \dots)

aparchSim(model = list(omega = 1.0e-6, alpha = 0.1, gamma = 0, 
	alpha.lags = 1, beta = 0.8, beta.lags = 1, delta = 1), n = 100, 
	innov = rand.gen(n, ...), n.start = 100, start.innov = NULL, 
	rand.gen = rnorm, \dots)	
aparchFit(x, order = list(alpha.lags = 1, beta.lags = 1, delta = 2), 
	opt = list(gamma = FALSE, delta = FALSE, disparm = FALSE), 
	distribution = c("norm", "t", "symstb"), disparm = c(1, 4, 1.9), 
	n.cond = NULL, doprint = TRUE, method = "Nelder-Mead", \dots)

\method{print}{fAPARCH}(x, \dots)
\method{summary}{fAPARCH}(object, \dots)
\method{print.summary}{fAPARCH}(x, \dots)
}


\arguments{

  	\item{disparm}{ 
	    the distribution parameter. For the distribution
	    "norm" \code{disparm} will not be used, for the "Student-t"
	    distribution the distribution parameter is the number of degrees
	    of freedom, and for the symmetric stable "symstb" distribution
	    the distribution parameter is the tail index alpha.
	    }
  	\item{distribution}{
	    a character string describing the distribution of innovations. 
	    By default the optimization is based on gaussian log likelihood 
	    parameter optimization denoted by "norm". Alternatively, a 
	    "Student-t" or "symmetric stable", "symstb" can be chosen.
	    }
  	\item{doprint}{
	    a logical, if set to \code{TRUE}, the iteration
	  	path of the optimization will be printed.
	  	}
	\item{innov}{
		a univariate time series or vector of innovations to 
		produce the series. If not provided, \code{innov} will 
		be generated using \code{rand.gen}. Missing values are 
		not allowed. A numeric vector.
		}	
	\item{method}{
	    a character string denoting the optimization method,
	    by default "Nelder-Mead".
	    }
	 \item{model}{
		List of GARCH model parameters: 
		\code{omega} the constant coefficient of the variance equation, 
			must be defined; 
		\code{alpha} the vector of autoregressive coefficients, must be 
			defined; 
		\code{beta} the vector of variance coefficients, optional; 
		\code{mu}, the mean value.
		\cr
		List of APARCH model parameters:
		\code{omega} the omega parameter, a numeric value;
		\code{alpha} the "ar" coefficients, a numeric vector;
		\code{gamma} the asymmetry coefficients, a numeric vector of same 
		  	length as "alpha";
		\code{alpha.lags} an integer vector denoting to which lags the 
		  	"alpha" coefficients belong;
		\code{beta} the "ma" coefficients, a numeric vector;
		\code{beta.lags} an integer vector denoting to which lags the 
		  	"beta" coefficients belong;
		\code{delta} the "delta" exponent.
		The default model is Taylor Schwert GARCH(1,1) model.
		}
	\item{n}{
		length of output series, an integer value.
		}
	\item{n.cond}{
	    number of omitted start terms on which the MLE is conditioned.
	    If set to NA, the number of terms is automatically set to the
	    sum of the two largest lags of the \code{alpha} and \code{beta}
	    coefficients.
	    }
	\item{n.start}{
		the number of start-up values. The start-up innovations 
		will be generated by \code{rand.gen} if \code{start.innov} 
		is not provided. An integer value by default 100.
		Missing values are not allowed.
		}
  	\item{object}{
  		[summary] - 
		a fitted GARCH or APARCH time series object.
		}
	\item{opt}{
	    vector of logicals, determins which parameters will be optimized.
	    By default, the \code{gamma} coefficients, the \code{delta}
	    exponent and the \code{disparm} distribution parameters are
	    excluded from the optimization process. 
	    Note, the \code{alpha} and \code{beta} coefficients cannot be
	    excluded from optimization.
	    }
	\item{order}{
	    a specification list for the GARCH or APARCH model: 
	    \cr
		[garch] -
		A two dimensional integer vector giving the orders of the
		model to fit. \code{order[1]} corresponds to the GARCH part and
		\code{order[2]} to the ARCH part.
		The default specification belongs to a symmetric GARCH(1,1) model.
		\cr
		[aparch] - 
		\code{alpha.lags} an integer vector denoting to which lags the 
		  	"alpha" coefficients belong, by default 1;
		\code{beta.lags} an integer vector denoting to which lags the 
		  	"beta" coefficients belong, by default 1;
		\code{gamma} -- symmetry coefficients, a numeric vector of same 
		  	length as "alpha.lags", by default 0;
		\code{delta} -- the "delta" exponent, by default 2.
		The default specification belongs to a symmetric GARCH(1,1) model.
		}
	\item{rand.gen}{
		optional, a function to generate the innovations.
		}	
	\item{start.innov}{	
		a univariate time series or vector of innovations to be 
		used as start up values. Missing values are not allowed.
		A numeric vector.
		}
	\item{x}{
		an univariate vector or time series. \cr
  		[print][print.summary] - 
		a fitted GARCH or APARCH time series object.
		}
	\item{\dots}{
		additional arguments to be passed.
		For \code{garchSim} passed to \code{rand.gen}, most usefully,
		the standard deviation of the innovations generated by \code{rnorm}
		can be specified by \code{sd}.
		For \code{garchFit} passed to\code{\link{qr}} when computing
		the asymptotic standard errors of \code{coef}.
		}	

}


\details{
  
	\bold{GARCH Modelling:}
	\cr\cr
	\code{garchFit} uses a Quasi-Newton optimizer to find the maximum
  	likelihood estimates of the conditionally normal model. The first
  	max(p,q) values are assumed to be fixed. The optimizer uses a hessian
  	approximation computed from the BFGS update. Only a Cholesky factor
  	of the Hessian approximation is stored. For more details see Dennis
  	et al. (1981), Dennis and Mei (1979), Dennis and More (1977), and
  	Goldfarb (1976). The gradient is either computed analytically or
  	using a numerical approximation.
  	\cr
  	\code{[tseries:garch]}
  	\cr
  	
  	\bold{APARCH Modelling:}
  	\cr\cr
  	\code{aparchFit} allows to estimate a whole family of ARCH models.
	For Engle's ARCH(p) model one has to set \code{beta.lags=1}, beta=0, 
   	and \code{opt$beta=FALSE}. 
	For Bollerslev's GARCH(p,q) model, just use it.
	For a Taylor-Schwert TS-GARCH(p,q) model one has to set \code{delta=1}.
	For Gosten et al.'s GJR(p,q) model one has to set \code{gamma} and 
   	code{opt.gamma=TRUE}.
	For the extimation of parameters from asymmetric models and models 
   	with unknown \code{delta} exponents different from 2 one has to set 
   	the arguments \code{opt$gamma=TRUE} and \code{opt$delta=TRUE}.
	In addition from three types of innovations, normal distributed,
   	Student-t and symmetric stable can be chosen.
  	
}


\value{

	\code{garchSim}\cr
	\code{aparchSim}
	\cr
	return objects of class \code{ts}.

	\code{garchFit}\cr
	\code{aparchFit}
	\cr
	return lists of class \code{fGARCH} 
	and \code{fAPARCH}, respectivley with at least the following 
	components:

  	\item{order}{
		the order of the fitted model.
		}
  	\item{coef}{
		estimated GARCH coefficients for the fitted model.
		}
  	\item{n.likeli}{
		the negative log-likelihood function evaluated at the
		coefficient estimates (apart from some constant).
		}
  	\item{n.used}{
		the number of observations of \code{x}.
		}
  	\item{residuals}{
		the series of residuals.
		}
  	\item{fitted.values}{
		the bivariate series of conditional standard
		deviation predictions for \code{x}.
		}
  	\item{series}{
		the name of the series \code{x}.
		}
  	\item{frequency}{
		the frequency of the series \code{x}.
		}
  	\item{call}{
		the call of the \code{garch} function.
		}
  	\item{asy.se.coef}{
		the asymptotic-theory standard errors of the
		coefficient estimates.
		}
	
}


\references{

Bera A.K., Higgins M.L. (1993);
	\emph{ARCH Models: Properties, Estimation and Testing},
	J. Economic Surveys 7, 305--362.
  
Bollerslev T. (1986);
	\emph{Generalized Autoregressive Conditional Heteroscedasticity},
	Journal of Econometrics} 31, 307--327.

Engle R.F. (1982);
	\emph{Autoregressive Conditional Heteroscedasticity with Estimates 
	of the Variance of United Kingdom Inflation},
	Econometrica 50, 987--1008.

Dennis J.E., Gay D.M., Welsch R.E. (1981);
	\emph{Algorithm 573 -- An Adaptive Nonlinear Least-Squares Algorithm};
	ACM Transactions on Mathematical Software 7, 369--383.

Dennis J.E., Mei H.H.W. (1979);
	\emph{Two New Unconstrained Optimization Algorithms which use 
	Function and Gradient Values},
	J. Optim. Theory Applic. 28, 453--482.

Dennis J.E., More J.J. (1977);
	\emph{Quasi-Newton Methods, Motivation and Theory};
	SIAM Revue 19, 46--89.

Goldfarb D. (1976);
	\emph{Factorized Variable Metric Methods for Unconstrained Optimization},
	Math. Comput. 30, 796--811.
	
}


\author{

    Adrian Trapletti for the \code{[tseries:garch]} function, \cr
    D. M. Gay for the Fortran optimizer.
    Diethelm Wuertz Diethelm Wuertz for this \R-port. 
     
}


\seealso{
  
	\code{\link{armaModelling}}.
	
}


\examples{
## 	GARCH -
	xmpSeries("\nStart: Model Bollerslev's GARCH(1,1) Process >")
   	# Simulate a time series of length 1000:
   	ts = garchSim(model = list(omega = 1e-6, alpha = 0.1, beta = 0.8, 
   	  	h0 = 1e-7), n = 1000)
	xmpSeries("\nNext: Estimate the parameters >")
   	fit = garchFit(ts, order = c(1, 1))
   	print(fit) 
   	xmpSeries("\nNext: Summary and Diagnostic Analysis >")
   	summary(fit)  

## 	APARCH -
	xmpSeries("\nNext: Subset TS-GARCH(1,5[1,5]), delta fixed >")
   	# Simulate a time series of length 1000:
   	ts = aparchSim(model=list(omega=1e-6, alpha=0.1, gamma=0, 
   		alpha.lags=1, beta=c(0.5, 0.3), beta.lags=c(1, 5), delta=1),
        innov=rnorm(5000), start.innov=rnorm(1000))
    par(mfrow = c(2, 2), cex = 0.6)
    ts.plot(ts, main = "Subset TS GARCH(1,5) - Mormal")
    acf(abs(ts), lag.max = 20)
    xmpSeries("\nNext: Estimate the parameters >")
    aparchFit(ts, order=list(alpha.lags = 1, beta.lags = c(1, 5), delta = 1),
        opt=list(gamma=FALSE, delta=FALSE, disparm=FALSE), doprint=FALSE)
    # For more examples type: xmpfSeries() ...
}


\keyword{models}


\eof
\name{randomInnovations}

\alias{randomInnovations}

\alias{set.lcgseed}
\alias{get.lcgseed}
\alias{runif.lcg}
\alias{rnorm.lcg}
\alias{rt.lcg}

\title{Generator for random Innovations}


\description{

	A collection of functions to generate portable random innovations.
	The function runs under R and SPlus and generates the same
	sequence of random numbers. Supported are uniform, normal and 
	Student-t distributed random numbers.
		
	The functions are:
	
	\tabular{rll}{
		1  	\tab 	\code{set.lcgseed}	 	
			\tab	Set initial random seed, \cr
		2  	\tab 	\code{get.lcgseed}		
			\tab	Get the current valus of the random seed, \cr
		3  	\tab 	\code{runif.lcg}		
			\tab	Uniform linear congruational generator, \cr
		4  	\tab 	\code{rnorm.lcg}		
			\tab	Normal linear congruational generator, \cr
		5  	\tab 	\code{rt.lcg}			
			\tab	Student-t linear congruential generator. }
	
}


\usage{
set.lcgseed(seed = 4711)
get.lcgseed()
runif.lcg(n, min = 0, max = 1)
rnorm.lcg(n, mean = 0, sd = 1)
rt.lcg(n, df)	
}


\arguments{

  	\item{df}{
    	number of degrees of freedom, a positive integer, maybe 
    	non-integer.
    	}
    \item{mean, sd}{
  		means and standard deviation of the normal distributed 
  		innovations.
  		}
  	\item{min, max}{
    	lower and upper limits of the uniform distributed 
    	innovations.
    	}
    \item{seed}{
  		an integer value, the random number seed.
  		}
  	\item{n}{
  		an integer, the number of random innovations to be 
  		generated.
  		}
  			
}


\details{
	
	A simple portable random number generator for use in R and 
	SPlus. We recommend to use this generator only for comparisons 
	of calculations in R and Splus.

	The generator is a linear congruential generator with parameters
	\code{LCG(a=13445, c=0, m=2^31-1, X=0)}. It is a simple random 
	number generator which passes the bitwise randomness test.

}


\value{

  	A vector of generated random innovations. The value of the
  	current seed is stored in the variable \code{lcg.seed}.
  	
}


\references{

Altman, N.S. (1988);
	\emph{Bitwise Behavior of Random Number Generators},
 	 SIAM J. Sci. Stat. Comput., 9(5), September, 941--949.

}


\author{

	Diethelm Wuertz for this \R-port.
	
}


\seealso{

	\code{\link{runif}},
	\code{\link{rnorm}},
	\code{\link{rt}}.
	
}


\examples{
## set.lcgseed -
   xmpSeries("\nStart: Set Initial Seed >")
   set.lcgseed(seed = 65890)
 
## runif.lcg - rnorm.lcg - rt.lcg -
   xmpSeries("\nNext: Create Random Numbers >")
   cbind(runif.lcg(10), rnorm.lcg(10), rt.lcg(10, df = 4))

## get.lcgseed -
   xmpSeries("\nNext: What is the current value of the seed? >")
   get.lcgseed()  
   
## Note, to overwrite rnorm, use
   # rnorm = rnorm.lcg
   # Going back to rnorm
   # rm(rnorm)
}


\keyword{programming}


\eof
\name{tseriesTests}

\alias{tseriesTests}

\alias{tsTest}
\alias{adfTest}
\alias{bdsTest}
\alias{jbTest}
\alias{kpssTest}
\alias{poTest}
\alias{ppTest}
\alias{tnnTest}
\alias{wnnTest}

\title{Time Series Tests}


\description{

	A collection of functions for testing various aspects of time series, 
	including unit roots, independence, normality of the distribution, 
	trend stationary, cointegration and neglected nonlinearities.
	\cr
	
	The family of time series tests includes the following 
	hypothesis tests:
		
	\tabular{rll}{
	 	1	\tab 	\code{adfTest} 	
	 		\tab  	Augmented Dickey--Fuller test for unit roots, \cr
		2	\tab 	\code{bdsTest}	
			\tab  	Brock--Dechert--Scheinkman test for iid series, \cr
		3	\tab 	\code{jbTest} 	
			\tab  	Jarque--Bera Test for normality, \cr
		4	\tab 	\code{kpssTest} 	
			\tab  	KPSS test for level or trend stationary, \cr
		5	\tab 	\code{poTest} 	
			\tab  	Phillips--Ouliaris test for cointegration, \cr
		6	\tab 	\code{ppTest} 	
			\tab  	Phillips--Perron test for unit roots, \cr	
		7	\tab 	\code{tnnTest} 	
			\tab  	Teraesvirta NN test for neglected nonlinearity, \cr
		8	\tab 	\code{wnnTest} 	
			\tab  	White NN test for neglected nonlinearity.}
	
}


\note{

	There is nothing really new in this package. 
	The benefit you will get from this help page, that we bring together
	a broad collection of time series tests from several \R-packages 
	which may be of interest for economists and financial engineers.
	
	On the other hand the user can still use the underlying function
	calls from the imported \R-packages.
	
	The output of the various hypothesis tests is an object of class
	\code{htest}. The associated \code{print} method gives an unique 
	report about the test results.
	
}


\usage{
adfTest(x, alternative = c("stationary", "explosive"), k)
bdsTest(x, m = 3, eps = seq(0.5*sd(x), 2*sd(x), length = 4), trace = FALSE)
jbTest(x)
kpssTest(x, null = c("Level", "Trend"), lshort = TRUE)
poTest(x, demean = TRUE, lshort = TRUE) 
ppTest(x, alternative = c("stationary", "explosive"), 
	type = c("Z(alpha)", "Z(t_alpha)"), lshort = TRUE)
tnnTest(x, lag = 1, type = c("Chisq", "F"), scale = TRUE, \dots) 
wnnTest(x, lag = 1, qstar = 2, q = 10, range = 4, 
	type = c("Chisq", "F"), scale = TRUE, \dots) 
}


\arguments{
  
  	\item{alternative, null}{
		In the case of \code{alternative}, the argument indicates an 
		alternative hypothesis. The choice must be one of the elements 
		specified in the input vector, by default the first entry is 
		selected.
		In the case of \code{null}, the argument indicates for the
		\code{kpssTest} the null hypothesis and must be one of 
		\code{"Level"} (default) or \code{"Trend"}. You can specify 
		just the initial letter.
		}
  	\item{demean}{
		a logical indicating whether an intercept is included in
		the cointegration regression or not.
		}
  	\item{eps}{
		a numeric vector of epsilon values for close points. The
		BDS test is computed for each element of \code{eps}. It should 
		be set in terms of the standard deviation of \code{x}.
		}
  	\item{k}{
		the lag order to calculate the test statistic.
		}
  	\item{lag}{
		an integer which specifies the model order in terms of lags.
		}
  	\item{lshort}{
		a logical indicating whether the short or long version
		of the truncation lag parameter is used.
		}
  	\item{m}{
		an integer indicating that the BDS test statistic is computed
		for embedding dimensions \code{2}, \dots, \code{m}.
		}
  	\item{q}{
		an integer representing the number of phantom hidden units
		used to compute the test statistic.
		}
  	\item{qstar}{
		the test is conducted using \code{qstar} principal
		components of the phantom hidden units. The first principal
		component is omitted since in most cases it appears to be collinear
		with the input vector of lagged variables. This strategy preserves
		power while still conserving degrees of freedom.
		}
  	\item{range}{
		the input to hidden unit weights are initialized uniformly
		over \code{[-range/2, range/2]}.
		}
  	\item{scale}{
		a logical indicating whether the data should be scaled 
		before computing the test statistic. The default arguments to
		\code{\link{scale}} are used.
		}
  	\item{trace}{
		a logical indicating whether some informational output is
		traced.
		}
  	\item{type}{
    	indicates which variant of a test will be computed. The choice 
    	must be one of the elements specified in the input vector, by 
    	default the first entry is selected.
    	} 
    \item{x}{
		a numeric vector or time series.
		}	
    \item{\dots}{
		further arguments to be passed from or to methods.
		}	

}


\details{

	\bold{Augmented Dickey--Fuller Test for Unit Roots:}
	\cr\cr
	The general regression equation which incorporates a constant and a
	linear trend is used and the t-statistic for a first order
	autoregressive coefficient equals one is computed. The number of lags
	used in the regression is \code{k}. The default value of
	\code{trunc((length(x)-1)^(1/3))} corresponds to the suggested upper
	bound on the rate at which the number of lags, \code{k}, should be
	made to grow with the sample size for the general \code{ARMA(p,q)}
	setup. Note that for \code{k} equals zero the standard Dickey-Fuller
	test is computed. The p-values are interpolated from Table 4.2, p. 103
	of Banerjee et al. (1993). If the computed statistic is outside the
	table of critical values, then a warning message is generated. 
	Note, that missing values are not allowed. 
	\cr
	\code{[tseries:adf.test]}
	\cr
	
	\bold{Brock--Dechert--Sheinkman Test:}
	\cr\cr
	The \code{bdsTest} test examines the \emph{spatial dependence} of the 
	observed series. To do this, the series is embedded in \code{m}-space 
	and the dependence of \code{x} is examined by counting \emph{near} 
	points. Points for which the distance is less than \code{eps} are 
	called near. The BDS test statistic is asymptotically standard Normal.
  	Note, that missing values are not allowed.
	There is a special print method for objects of class \code{"bdsTest"}
  	which by default uses 4 digits to format real numbers. 
  	\cr
  	\code{[tseries:bds.test]}
  	\cr
	
	\bold{Jarque--Bera Test:}
	\cr\cr
	The \code{jbTest} evaluates the hypothesis that the series has a 
	normal distribution with unspecified mean and variance, against the 
	alternative that the series does not have a normal distribution. The 
	test is based on the sample skewness and kurtosis. For a true normal 
	distribution, the sample skewness should be near 0 and the sample 
	kurtosis should be near 3. The Jarque-Bera test determines whether 
	the sample skewness and kurtosis are unusually different than their 
	expected values, as measured by a chi-square statistic. The Jarque-Bera 
	test is an asymptotic test, and should not be used with small samples. 
	You may want to use the \code{lillieTest} for small samples. 
	\cr
	\code{[jb.test]}
	\cr
	
	\bold{Kwiatkowski--Phillips--Schmidt--Shin Test:}
	\cr\cr
	To estimate \code{sigma^2} the Newey-West estimator is used.
  	If \code{lshort} is \code{TRUE}, then the truncation lag parameter is
  	set to \code{trunc(3*sqrt(n)/13)}, otherwise
  	\code{trunc(10*sqrt(n)/14)} is used.  The p-values are interpolated
  	from Table 1 of Kwiatkowski et al. (1992). If the computed statistic
  	is outside the table of critical values, then a warning message is
  	generated. 
  	\cr
  	\code{[tseries:kpss.test]}
  	\cr
	
	\bold{Phillips--Ouliaris Test:}
	\cr\cr
	The \code{poTest} Z(alpha) statistic for a unit root in the
  	residuals of the cointegration regression is computed, see also
  	\code{ppTest}. The unit root is estimated from a regression of
  	the first variable (column) of \code{x} on the remaining variables of
  	\code{x} without a constant and a linear trend.  To estimate
  	\code{sigma^2} the Newey-West estimator is used.  If \code{lshort} is
  	\code{TRUE}, then the truncation lag parameter is set to
  	\code{trunc(n/100)}, otherwise \code{trunc(n/30)} is used.  The
  	p-values are interpolated from Table Ia and Ib, p. 189 of Phillips and
  	Ouliaris (1990).  If the computed statistic is outside the table of
  	critical values, then a warning message is generated. The dimension 
  	of \code{x} is restricted to six variables. 
  	\cr
  	\code{[tseries:po.test]}
  	\cr  
  	
	\bold{Phillips--Perron Test:}
	\cr\cr	
	The general regression equation which incorporates a constant and a
  	linear trend is used and the \code{Z(alpha)} or \code{Z(t_alpha)}
  	statistic for a first order autoregressive coefficient equals one are
  	computed.  To estimate \code{sigma^2} the Newey-West estimator is
  	used.  If \code{lshort} is \code{TRUE}, then the truncation lag
  	parameter is set to \code{trunc(4*(n/100)^0.25)}, otherwise
  	\code{trunc(12*(n/100)^0.25)} is used.  The p-values are interpolated
  	from Table 4.1 and 4.2, p. 103 of Banerjee et al. (1993).  If the
  	computed statistic is outside the table of critical values, then a
  	warning message is generated. 
  	\cr
  	\code{[tseries:pp.test]}
  	\cr
  
  	\bold{Teraesvirta Neural Network Test:}
  	\cr\cr	
  	The null is the hypotheses of linearity in \code{mean}. This test 
  	uses a Taylor series expansion of the activation function to 
  	arrive at a suitable test statistic. If \code{type} equals \code{"F"}, 
  	then the F-statistic instead of the Chi-Squared statistic
	is used in analogy to the classical linear regression. 
  	Missing values are not allowed. 
  	\cr 
  	\code{[tseries:teraesvirta.test]}
  	\cr
	
	\bold{White Neural Network Test:}
	\cr\cr
	The null is the hypotheses of linearity in ``mean''. This
	type of test is consistent against arbitrary nonlinearity
	in mean. If \code{type} equals \code{"F"}, then the F-statistic
	instead of the Chi-Squared statistic is used in analogy to the
	classical linear regression. 
	\cr
	\code{[tseries:white.test]}
	
}


\value{

	A list with class \code{"htest"} containing the following 
	components:

	\item{statistic}{
		the value of the test statistic.
		}
	\item{parameter}{
		the lag order.
		}
	\item{p.value}{
		the p-value of the test.
		}
	\item{method}{
		a character string indicating what type of test was
		performed.
		} 
	\item{data.name}{
		a character string giving the name of the data.
		}
	\item{alternative}{
		a character string describing the alternative
		hypothesis.
		}
		
}


\references{
Banerjee A., Dolado J.J., Galbraith J.W., Hendry D.F. (1993);
	\emph{Cointegration, Error Correction, and the Econometric 
	Analysis of Non-Stationary Data},
	Oxford University Press, Oxford.

Brock, W.A., Dechert W.D., Sheinkman J.A. (1987); 
	\emph{A Test of Independence Based on the Correlation 
	Dimension}, 
	SSRI no. 8702, Department of Economics, University of 
	Wisconsin, Madison.

Conover, W.J. (1980);
 	\emph{Practical Nonparametric Statistics}, 
 	New York, Wiley. 

Cromwell J.B., Labys W.C., Terraza M. (1994);
	\emph{Univariate Tests for Time Series Models},
	Sage, Thousand Oaks, CA, pages 32--36.
	
Kwiatkowski D., Phillips P.C.B, Schmidt P., Shin Y. (1992);
	\emph{Testing the Null Hypothesis of Stationarity against 
	the Alternative of a Unit Root},
	Journal of Econometrics 54, 159--178.
		
Lee T.H., White H., Granger C.W.J. (1993); 
	\emph{Testing for neglected nonlinearity in time series models},
	Journal of Econometrics 56, 269--290.
	
Perron P. (1988);
	\emph{Trends and Random Walks in Macroeconomic Time Series},
	Journal of Economic Dynamics and Control 12, 297--332.

Phillips P.C.B., Ouliaris S. (1990);
	\emph{Asymptotic Properties of Residual Based Tests for Cointegration},
	Econometrica 58, 165--193.
  	
Said S.E., Dickey D.A. (1984);
	\emph{Testing for Unit Roots in Autoregressive-Moving Average 
	Models of Unknown Order},
	Biometrika 71, 599--607.

Teraesvirta T., Lin C.F., Granger C.W.J. (1993);
	\emph{Power of the Neural Network Linearity Test},
	Journal of Time Series Analysis 14, 209--220.
	
}


\author{

	Adrian Trapletti for the tests from \R's tseries package,\cr
	Blake LeBaron for the \code{bds} C program,\cr 
	Diethelm Wuertz for this \R-port.
}


\seealso{

	\code{classicalTests},
	\code{\link{lmTests}}.
	
}


\examples{
## adfTest - 
   xmpSeries("\nStart: Augmented Dickey-Fuller Test for Unit Roots >")
   # A time series which contains no unit-root:
   x = rnorm(1000)  
   adfTest(x)
   # A time series which contains a unit-root:
   y = diffinv(x)
   adfTest(y)
   
## bdsTest -
   xmpSeries("\nNext: Brock-Dechert-Sheinkman Test for iid Series >")
   # iid Time Series:
   par(mfrow = c(3,1))
   x = rnorm(100)
   plot(x, type = "l", main = "iid Time Series")
   bdsTest(x, m = 3)
   # Non Identically Distributed Time Series:
   x = c(rnorm(50), runif(50))
   plot(x, type = "l", main = "Non-iid Time Series")
   bdsTest(x, m = 3)  
   # Non Independent Innovations from Quadratic Map:
   x = rep(0.2, 100)
   for (i in 2:100) x[i] = 4*(1-x[i-1])*x[i-1]
   plot(x, type = "l", main = "Quadratic Map")
   bdsTest(x, m = 3)
   
## jbTest -
   xmpSeries("\nNext: Jarque-Bera Test for Normality >")
   # Null:
   x = rnorm(100)
   jbTest(x)
   # Alternative:
   x = runif(100)
   jbTest(x)
   
## kpssTest -
   xmpSeries("\nNext: KPSS test for Level or Trend Stationary >")
   # Time Series is Level Stationary:
   x = rnorm(1000)
   kpssTest(x)
   # Time Series has Unit Root:
   y = cumsum(x)
   kpssTest(y)
   # Time Series is Trend Stationary:
   x = 0.3*(1:1000)+rnorm(1000)
   kpssTest(x, null = "Trend")
   
## poTest -
   xmpSeries("\nNext: Phillips-Ouliaris Test for Cointegration >")
   # Non-Cointegrated Case:
   x = ts(diffinv(matrix(rnorm(2000), 1000, 2)))
   poTest(x)
   # Cointegrated Case:
   x = diffinv(rnorm(1000))
   y = 2.0 - 3.0*x + rnorm(x, sd=5)
   z = ts(cbind(x, y))
   poTest(z)
   
## ppTest -
   xmpSeries("\nNext: Phillips-Perron Test for Unit Roots >")
   # The Time Series has no Unit Root:
   x = rnorm(1000)
   ppTest(x)
   # The Time Series has Unit Root:
   y = cumsum(x)  
   ppTest(y)
   
## tnnTest -
   xmpSeries("\nNext: Teraesvirta NN test for Neglected Nonlinearity >")
   # Time Series Non-linear in ``mean'' regression 
   par(mfrow = c(2, 1))
   n = 1000
   x = runif(1000, -1, 1)  
   tnnTest(x)
   # Generate time series which is nonlinear in ``mean''
   x[1] = 0.0
   for (i in (2:n)) {
     x[i] = 0.4*x[i-1] + tanh(x[i-1]) + rnorm (1, sd = 0.5) }
   plot(x, main = "Teraesvirta Test", type = "l")
   tnnTest(x)
   
## wnnTest -
   xmpSeries("\nNext: White NN test for Neglected Nonlinearity >")
   # Time Series Non-Linear in ``mean'' Regression
   par(mfrow = c(2, 1))
   n = 1000
   x = runif(1000, -1, 1)
   wnnTest(x)
   # Generate time series which is nonlinear in ``mean''
   x[1] = 0.0
   for (i in (2:n)) {
     x[i] = 0.4*x[i-1] + tanh(x[i-1]) + rnorm (1, sd = 0.5) }
   plot(x, main = "White Test", type = "l")
   wnnTest(x)                     
}


\keyword{htest}


\eof
\name{regressionModelling}

\alias{regressionModelling}

\alias{fREG}
\alias{fREG-class}

%
\alias{regFit}

\alias{predict.fREG}

\alias{print.fREG}
\alias{plot.fREG}
\alias{summary.fREG}

\alias{fitted.values.fREG}
\alias{residuals.fREG}


% BUILTINs:

\alias{BImars}
\alias{BIpolymars}
\alias{predictBImars} 
\alias{predictBIpolymars} 
\alias{summaryBIpolymars}


\title{Univariate Regression Modelling}


\description{

	A collection of easy to use functions to perform a univariate
	regression analysis from several methods, to analyse and 
	summarize the fit, and to predict for new data records.
	
	This wrapper was mainly build for multivariate financial time
	series analysis.
	
	The functions and methods are:
	
	\tabular{rll}{
			\tab
			\tab	\cr
			\tab
			\tab	\bold{The Models Include:} \cr
		1	\tab 	\code{"LM"} 		 
			\tab  	Linear Modelling, \cr
		2	\tab 	\code{"GLM"} 	 
			\tab  	Generalized Linear Modelling, \cr
		3	\tab 	\code{"GAM"} 	 
			\tab  	Generalized Additive Modelling, \cr
		4	\tab 	\code{"PPR"} 	 
			\tab  	Projection Pursuit Regression, \cr
		5	\tab 	\code{"MARS"} 	 
			\tab  	Multivariate Adaptive Regression Splines, \cr
		6	\tab 	\code{"POLYMARS"} 
			\tab  	Polytochomous MARS, and \cr
		7	\tab 	\code{"NNET"} 	 
			\tab  	Feedforward Neural Network Modelling. \cr
			\tab
			\tab	\cr
			\tab
			\tab	\bold{Available Methods are:} \cr
		1	\tab 	\code{predict(object, newdata, ...)}  
			\tab    Predict method for objects of class 'fARMA', \cr
		2	\tab 	\code{print(x, ...)} 
			\tab    Print method for objects of class 'fARMA', \cr
		3	\tab 	\code{plot(x, ...)}  
			\tab    Plot method for objects of class 'fARMA', \cr
		4	\tab 	\code{summary(object, ...}  
			\tab    Summary method for objects of class 'fARMA', \cr
		5	\tab 	\code{fitted.values(object)}  
			\tab    Fitted values method for objects of class 'fARMA', \cr
		6	\tab 	\code{residuals(object)}
			\tab	Residuals method for objects of class 'fARMA'. }
		
	
	The print method prints the returned object from a regression 
	fit, and the summary method performs a diagnostic analysis and 
	summarizes the results of the fit in a detailed form. The plot
	method produces diagostic plots. The predict method forecasts 
	from new data records. Two other methods to print the fitted 
	values, and the residuals are available.
	
}
	

\notes{	
	
	This \code{regFit} function offers for several regression models
	an easy to use wrapper. There is nothing really new in this package. 
	However, the benefit you will get is, that all regression 
	models got a common argument list with a formula to desribe 
	the input data to be used, if rquired with an argument to specify
	the family function, and with a string to name the type of the 
	desired regression model. On the other hand, the user can pass 
	additional arguments to the underlying functions. This allows to 
	tailor the modelling process.
	\cr
	
	The output of the \code{print}, \code{plot}, \code{summary}, and 
	\code{predict} methods have all the same style of format. This 
	makes it very easy to compare and to interpret the results 
	obtained from different algorithms implemented in different 
	functions.
	\cr
	
	All beside two of the underlying functions are available in a default
	R Installation. They are already available or loaded when Rmetrics 
	is invoked. For \code{MARS} and \code{POLYMARS} we have implemented
	BUILTIN functions for parameter estimation and prediction, so that it
	is becomes not necessary to install the contribute \code{mars} and
	\code{polyspline} packages. Nevertheless, if loaded you can use them 
	in your environment, they don't intervene with Rmetrics.
	
}


\usage{
regFit(formula, family = gaussian(), data = list(), 
	method = c("LM", "GLM", "GAM", "PPR", "MARS", "POLYMARS", "NNET"), 
	nterms = NA, size = NA, title = "", description = "", \dots) 

\method{predict}{fREG}(object, newdata, type = "response", \dots)

\method{print}{fREG}(x, \dots)
\method{plot}{fREG}(x, y, \dots)
\method{summary}{fREG}(object, \dots)

\method{fitted.values}{fREG}(object, \dots)
\method{residuals}{fREG}(object, \dots)
}


\arguments{
  	
  	\item{data, newdata}{
	    \code{data} is the data frame containing the variables in the 
	    model. By default the variables are taken from 
	    \code{environment(formula)}, typically the environment from 
	    which \code{LM} is called. \code{newdata} is the data frame 
	    from which to predict.
	    }
  	\item{description}{
  		a brief description of the porject of type character.
  		}
  	\item{family}{
	    a description of the error distribution and link function to be 
	    used in \code{glm} and \code{gam} models. See \code{\link{glm}} 
	    and \code{\link{family}} for more details.
	    }
	\item{formula}{
	    a symbolic description of the model to be fit.
	    \cr
	    A typical \code{glm} predictor has the form \code{response ~ terms} 
	    where \code{response} is the (numeric) response vector and \code{terms}
	    is a series of terms which specifies a (linear) predictor for 
	    \code{response}. For \code{binomial} models the response can also 
	    be specified as a \code{factor}.
	    \cr
	    A \code{gam} formula, see also \code{gam.models}, allows
	    that smooth terms can be added to the right hand side of the 
	    formula. See \code{gam.side.conditions} for details and 
	    examples.
	    }  
	\item{method}{
	  	denotes the regression method by a character string used to fit 
	  	the model.
	    \code{method} must be one of the strings in the default argument.\cr
	    \code{"LM"}, for linear regression models, \cr
	    \code{"GLM"} for generalized linear modelling,\cr
		\code{"GAM"} for generalized additive modelling,\cr
		\code{"PPR"} for projection pursuit regression,\cr
		\code{"MARS"} for multivariate adaptive regression splines,\cr
		\code{"POLYMARS"} for molytochomous MARS, and\cr
		\code{"NNET"} for feedforward neural network modelling.
		}
    \item{nterms}{
    	[pprFit] - \cr
  		the number of terms to include in the final projection pursuit 
  		regression model. For further settings consult the 
	    \code{ppr} help page.
  		}
   	\item{object, x, y}{
    	is an object returned by the
    	regression function \code{regFit} and serves as input for the 
    	\code{predict}, \code{print}, \code{summary}, \code{print.summary},
    	and \code{plot} methods. Some methods allow for additional 
    	arguments to be passed.
    	}     
   \item{size}{
   		[nnetFit] - \cr
	    the number of units in the hidden layer of the feedforward
	    neural network model. For further settings consult the
	    \code{nnet} help page.
	    }
    \item{title}{
    	a title string.
    	}
    \item{type}{
    	[predict] - \cr
	    a string denoting the type of input data. By default set to
	    \code{"response"}.
	   }
    \item{\dots}{
    	additional optional arguments to be passed to the underlying 
    	functions. For details we refer to inspect the following help 
    	pages: \code{\link{lm}}, \code{\link{glm}}, \code{gam},
		\code{\link{ppr}}, \code{mars}, \code{polymars}, 
		or \code{nnet}. 
    	}
    	
}


\value{

  	\code{regFit} 
  	\cr
  	returns an S4 object of class \code{"fREG"}, with the folliwing 
  	slots:

  	\item{call}{
    	the matched function call.
    	}
  	\item{data}{
  		the input data in form of a data.frame.
  		}
  	\item{description}{
  		allows for a brief project description.
  		}
  	\item{fit}{
  		the results as a list returned from the underlying
  		regression model function, e.g.\cr
  		\code{fit$parameters} - the fitted model parameters,\cr
  		\code{fit$residuals} - the model residuals, \cr
  		\code{fit$fitted.values} - the fitted values of the model,\cr
  		and many more. For details we refer to the help pages of
  		the selected regression model. 
  		}
  	\item{method}{
    	the selected regression model naming the applied method.
		}
  	\item{formula}{
    	the formula expression describing the model.
    	}
    \item{family}{
    	the selected family and link name if available, otherwise
    	a string vector with to empty strings.
    	}
    \item{parameters}{
    	named parameters or coefficients of the fitted model.
    	}
    \item{title}[
    	a title string.}

    \cr\cr	
    \code{methods}
    \cr\cr
    
    The output from the \code{print} S3 method gives information at 
    least about the function call, the fitted model parameters,
    and the residuals variance.
    \cr\cr
    
    The \code{plot} S3 method produces three figures, the first plots
    the series of residuals, the second does a quantile-quantile plot
    of the residual plot, and the third plots the fitted values vs.
    the residuals. Additional plots can be generated from the plot
    method (if available) of the underlying model, see the example below. 
    \cr\cr
    
    The \code{summary} S3 method provides additional information,
    like errors on the model parameters as far as available, and adds 
    additional information about the fit.  
    \cr\cr
    
    The \code{predict} S3 method forecasts from a fitted model. The
    returned values are the same as produced by the prediction
    function of the selected regression model. Especially, \code{$fit} 
    returns the forecast vector.
    \cr\cr
     
    The \code{residuals} and \code{fitted.values} S3 methods return
    the residuals and the fitted values as numeric vectors.

}


\details{

  	\bold{LM -- Linear Modelling:}
  	\cr\cr 	
  	Univariate linear regression analysis is a statistical methodology 
  	that assumes a linear relationship between some predictor variables 
  	and a response variable. The goal is to estimate the coefficients 
  	and to predict new data from the estimated linear relationship.
	The function \code{plot.lm} provides four plots: a plot of residuals 
  	against fitted values, a Scale-Location plot of sqrt{| residuals |} 
  	against fitted values, a normal QQ plot, and a plot of Cook's 
  	distances versus row labels.
  	\cr 
  	\code{[stats:lm]}
  	\cr

	\bold{GLM -- Generalized Linear Models:}
	\cr\cr
	Generalized linear modelling extends the linear model in two directions.
  	(i) with a monotonic differentiable link function describing how the 
  	expected values are related to the linear predictor, and (ii) with 
  	response variables having a probability distribution from an exponential 
  	family. 
  	\cr
  	\code{[stats:glm]}
	\cr
  	
  	\bold{GAM -- Generalized Additive Models:}
  	\cr\cr	
  	An additive model generalizes a linear model by smoothing individually
  	each predictor term. A generalized additive model extends the additive
  	model in the same spirit as the generalized liner amodel extends the 
  	linear model, namely for allowing a link function and for allowing 
  	non-normal distributions from the exponential family. 
  	\cr
  	\code{[mgcv:gam]}
  	\cr
 	
  	\bold{PPR -- Projection Pursuit Regression:}
  	\cr\cr 	
  	The basic method is given by Friedman (1984), and is essentially 
  	the same code used by S-PLUS's \code{ppreg}. It is observed that 
  	this code is extremely sensitive to the compiler used. The algorithm 
  	first adds up to \code{max.terms}, by default \code{ppr.nterms},
  	ridge terms one at a time; it will use less if it is unable to find 
  	a term to add that makes sufficient difference. The levels of 
  	optimization (argument \code{optlevel}), by default 2, differ in 
  	how thoroughly the models are refitted during this process.
  	At level 0 the existing ridge terms are not refitted.  At level 1
  	the projection directions are not refitted, but the ridge
  	functions and the regression coefficients are. Levels 2 and 3 refit 
  	all the terms; level 3 is more careful to re-balance the contributions
  	from each regressor at each step and so is a little less likely to
  	converge to a saddle point of the sum of squares criterion. The 
  	\code{plot} method plots Ridge functions for the projection pursuit 
  	regression fit. 
  	\cr
  	\code{[stats:ppr]}
  	\cr
  	
  	\bold{MARS -- Multivariate Adaptive Regression Splines:}
  	\cr\cr
  	This function was coded from scratch, and did not use any of
  	Friedman's mars code.  It gives quite similar results to  Friedman's
  	program in our tests, but not exactly the same results.  We have not 
  	implemented Friedman's anova decomposition nor are categorical
  	predictors handled properly yet.  Our version does handle multiple
  	response variables, however.  As it is not well-tested, we would like
  	to hear of any bugs. 
  	\cr
  	Additional arguments which can be passed to the \code{"mars"}
  	estimator are:
  	\cr
	\code{w} - an optional vector of observation weights.
	\cr 
	\code{wp} - an optional vector of response weights. 
	\cr
	\code{degree} - an optional integer specifying maximum interaction 
	degree, default is 1. 
	\cr
	\code{nk} - an optional integer specifying the maximum number of model 
	terms. 
	\cr
	\code{penalty} - an optional value specifying the cost per degree of 
	freedom charge, default is 2.
	\cr 
	\code{thresh} - an optional value specifying forward stepwise stopping 
	threshold, default is 0.001. 
	\cr
	\code{prune} - an optional logical value specifying whether the model 
	should be pruned in a backward stepwise fashion, default is \code{TRUE}. 
	\cr
	\code{trace.mars} - an optional logical value specifying whether info 
	should be printed along the way, default is \code{FALSE}. 
	\cr
	\code{forward.step} - an optional logical value specifying whether 
	forward stepwise process should be carried out, default is \code{TRUE}. 
	\cr
	\code{prevfit} - optional data structure from previous fit. To see the 
	effect of changing the penalty paramater, one can use prevfit with 
	\code{forward.step = FALSE}. 
	\cr
  	\code{[mda:mars]}
 	\cr
  	
  	\bold{POLYMARS -- Polytochomous MARS:}
  	\cr\cr
  	The algorithm employed by \code{polymars} is different from the 
  	MARS(tm) algorithm of Friedman (1991), though it has many similarities. 
  	Also the name \code{polymars} has been used for this algorithm well 
  	before MARS was trademarked. 
  	%Two of the main differences are:
  	%\code{polymars} requires linear terms of a predictor to be in the model
  	%before nonlinear terms using the same predictor can be added; and
  	%\code{polymars} requires a univariate basis function to be in the model
  	%before a tensor-product basis function involving the univariate ...
  	\cr
  	Additional arguments which can be passed to the \code{"polymars"}
  	estimator are:
  	\cr
  	\code{maxsize} - the maximum number of basis functions that the model is 
  		allowed to grow to in the stepwise addition procedure. Default is 
		\eqn{\min(6*(n^{1/3}),n/4,100)}, where \code{n} is the number of 
		observations. 
		\cr
	\code{gcv} - parameter used to find the overall best model from a 
		sequence of fitted models. The residual sum of squares of a model 
		is penalized by dividing by the square of 
		\code{1-(gcv x model size)/cases}.   
		A larger gcv value would tend to produce a smaller model.
		\cr	
	\code{additive} - Should the fitted model be additive in the predictors? 
		\cr	
	\code{startmodel} - the first model that is to be fit by \code{polymars}. 
		It is either an object of the class \code{polymars} or a model 
		dreamed up by the user. In that case, it takes the form of a 
		\code{4 x n} matrix, where \code{n} is the  number of basis 
		functions in the starting model excluding the intercept. Each 
		row corresponds to one basis function (with two possible components). 
		Column 1 is the index of the first predictor involved. Column 2 is 
		a possible knot in this predictor. If column 2 is \code{NA}, the 
		first component is linear. Column 3 is the possible second predictor 
		involved (if column 3 is \code{NA} the basis function only depends 
		on one predictor). Column 4 contains the possible knot for the 
		predictor in column 3, and it is \code{NA} when this component is 
		linear.  Example: if a row reads \code{3 NA 2 4.7}, the corresponding 
		basis function is \eqn{[X_3 * (X_2-4.7)_+]}; if a row reads 
		\code{2 4.3 NA NA} the corresponding basis function is 
		\eqn{[(X_2-4.3)_+]}. 
		A fifth column can be added with 1s and 0s, The 1s specify which 
		basis functions of the startmodel must be in each model. Thus, these 
		functions stay in the model during the whole stepwise fitting 
		procedure. If \code{startmodel} is not specified \code{polymars} 
		starts with a model that only contains  the intercept. 
		\cr
	\code{weights} - optional vector of observation weights; if supplied, 
		the algorithm fits to minimize the sum of the weights multiplied 
		by the squared residuals. The length of weights must be the same 
		as the number of observations. The weights must be nonnegative. 
		\cr
	\code{no.interact} - an optional matrix used if certain predictor 
		interactions are not allowed in the model. It is given as a 
		matrix of size \code{2 x m}, with predictor indices as entries.  
		The two predictors of any row cannot have interaction terms with 
		each other. 
		\cr
	\code{knots} - defines how the function is to find potential knots 
		for the spline basis functions.  This can be set to the maximum 
		number of knots you would like to be considered for each predictor. 
		Usually, to avoid the design matrix becoming singular the actual 
		number of knots produced is constrained to at most every third 
		order statistic in any predictor. This constraint can be adjusted 
		using the \code{knot.space} argument. It can also be a vector with 
		the number of potential knots for each predictor. Again the actual 
		number of knots produced is constrained to be at most every 
		third order statistic any predictor.  
		A third possibility is to provide a matrix where each columns 
		corresponds to the ordered knots you would like to have considered 
		for that predictor. 
		This matrix should be filled out to a rectangular data structure 
		with NAs. 
		The default is \code{min(20, round(n/4))} knots per predictor. 
		When specifying knots as a vector an entry of \code{-1} indicates 
		that the predictor is a categorical variable and each unique entry 
		in it's column is treated as a  level. 
		When specifying knots as a single number or a matrix and there are 
		categorical variables these are specified separately as such using 
		the factor argument. 
		\cr
	\code{knot.space} - is an integer describing the minimum number of 
		order statistics apart that two knots can be. Knots should not 
		be too close to insure numerical stability. 
		\cr
	\code{ts.resp} - testset responses for model selection. Should have 
		the same number of columns as the training set response. A testset 
		can be used for the model selection. Depending on the value of 
		classify, either the model with the smallest testset residual 
		sum of squares or the smallest testset classification error is 
		provided. Overrides \code{gcv}. 
	 	\cr
	\code{ts.pred} - testset predictors. Should have the same number of 
		columns as the training set predictors. 
		\cr
	\code{ts.weights} -
		testset observation weights. A vector of length equal to the number 
		of cases of the testset. All weights must be non-negative. 
		\cr
	\code{classify} - when the response is discrete (categorical), polymars 
		can be used for classification. In particular, when 
		\code{classify = TRUE}, a discrete response with \code{K} levels 
		is replaced by \code{K} indicator variables as response. Model 
		selection is still being carried out using gcv, except when a 
		testset is provided, in which case testset misclassification is 
		used to select the best model. 
		\cr
	\code{factors} - used to indicate that certain variables in the predictor 
		set are categorical variables. Specified as a vector containing the 
		appropriate predictor indices (column numbers of categorical 
		variables in predictors matrix). Factors can also be set when the 
		\code{knots} argument is given as a vector, with \code{-1} as  
		the appropriate entries for factors. 
		\cr
	\code{tolerance} - for each possible candidate to be added/deleted 
		the resulting residual sums of squares of the model, with/without 
		this candidate, must be calculated. The inversion of of 
		the "X-transpose by X" matrix, X being the design matrix,  
		is done by an updating procedure c.f. C.R. Rao - Linear 
		Statistical Inference and Its Applications, 2nd. edition, page 33.   
		In the inversion the size of the bottom right-hand entry of this 
		matrix is critical. If it\code{s value is near zero or the value 
		of it}s inverse is almost zero then the  inversion procedure 
		becomes somewhat inaccurate. The lower the tolerance value the  
		more careful the procedure is in selecting candidates for addition 
		to the model but it may exclude too conservatively. And the other 
		hand if the tolerance is set too high a spurious result with a 
		singular or otherwise sub-optimal model may occur. By default 
		tolerance is set to 1.0e-5. 
		\cr
	\code{verbose} - when set  to \code{TRUE}, the function will print 
		out a line for each addition or deletion stage. For 
		example, " + 8 : 5 3.25 2 NA" means adding interaction basis 
		function of predictor 5 with knot at 3.25 and predictor 2 (linear), 
		to make a model of size 8, including intercept. 
  	\cr
  	\code{[polyclass:polymars]}
  	\cr\cr
  	
  	\bold{NNET -- Feedforward Neural Network Regression:}
  	\cr\cr	
  	If the response in \code{formula} is a factor, an appropriate 
	classification network is constructed; this has one output and 
	entropy fit if the number of levels is two, and a number of 
	outputs equal to the number of classes and a softmax output 
	stage for more levels. If the response is not a factor, it is 
	passed on unchanged to \code{nnet.default}. A quasi-Newton 
	optimizer is used, written in \code{C}. 
	\cr
	\code{[nnet:nnet]}
  	
}


\author{

	The R core team for the \code{lm} functions from R's \code{base} package, \cr
	B.R. Ripley for the \code{glm} functions from R's \code{base} package, \cr
	S.N. Wood for the \code{gam} functions from R's \code{mgcv} package, \cr
	N.N. for the \code{ppr} functions from R's \code{modreg} package, \cr
	T. Hastie, R. Tibshirani for the \code{mars} functions from R's \code{?} package, \cr
	M. O' Connors for the \code{polymars} functions from R's \code{?} package, \cr
	The R core team for the \code{nnet} functions from R's \code{nnet} package. \cr

}



\references{

Belsley D.A., Kuh E., Welsch R.E. (1980);
	\emph{Regression Diagnostics};
	Wiley, New York.
	
Dobson, A.J. (1990);
	\emph{An Introduction to Generalized Linear Models};
	Chapman and Hall, London.

Draper N.R., Smith H. (1981);
	\emph{Applied Regression Analysis}; 
	Wiley, New York.

Friedman, J.H. (1991); 
	\emph{Multivariate Adaptive Regression Splines (with discussion)},
	The Annals of Statistics 19, 1--141.
	
Friedman J.H., and Stuetzle W. (1981); 
	\emph{Projection Pursuit Regression}; 
	Journal of the American Statistical Association 76, 817-823.

Friedman J.H. (1984);
	\emph{SMART User's Guide}; 
	Laboratory for Computational Statistics, 
	Stanford University Technical Report No. 1.
	
Green, Silverman (1994);
	\emph{Nonparametric Regression and Generalized Linear Models};
	Chapman and Hall.

Gu, Wahba (1991); 
	\emph{Minimizing GCV/GML Scores with Multiple
		Smoothing Parameters via the Newton Method};
	SIAM J. Sci. Statist. Comput. 12, 383-398.

Hastie T., Tibshirani R. (1990);
	\emph{Generalized Additive Models};
	Chapman and Hall, London.

Kooperberg Ch., Bose S., and  Stone C.J. (1997);
	\emph{Polychotomous Regression},
	Journal of the American Statistical Association 92, 117--127.

McCullagh P., Nelder, J.A. (1989);
	\emph{Generalized Linear Models};
	Chapman and Hall, London.

Myers R.H. (1986);
	\emph{Classical and Modern Regression with Applications}; 
	Duxbury, Boston.

Rousseeuw P.J., Leroy, A. (1987);
	\emph{Robust Regression and Outlier Detection};
	Wiley, New York.

Seber G.A.F. (1977);
	\emph{Linear Regression Analysis}; 
	Wiley, New York.

Stone C.J., Hansen M., Kooperberg Ch., and Truong Y.K. (1997);
 	\emph{The use of polynomial splines and their tensor products 
 		in extended linear modeling (with discussion)}.

Venables, W.N., Ripley, B.D. (1999);
	\emph{Modern Applied Statistics with S-PLUS}; 
	Springer, New York.
	
Wahba (1990); 
	\emph{Spline Models of Observational Data};
	SIAM.

Weisberg S. (1985);
	\emph{Applied Linear Regression};  
	Wiley, New York.
	
Wood (2000); 
	\emph{Modelling and Smoothing Parameter Estimation  with
	Multiple  Quadratic Penalties};
	JRSSB 62, 413-428.

Wood (2001); 
	\emph{mgcv: GAMs and Generalized Ridge Regression for \R}.
	R News 1, 20-25.

Wood (2001);
	\emph{Thin Plate Regression Splines}.


	There exists a vast literature on regression. The references listed 
	above are just a small sample of what is available. The book by 
	Myers' is an introductory text book that covers discussions of much 
	of the recent advances in regression technology. Seber's book is 
	at a higher mathematical level and covers much of the classical theory 
	of least squares.
	
}


\seealso{

  	\code{\link{lm}}, 
  	\code{\link{glm}},
  	\code{gam},
  	\code{\link{ppr}},
  	\code{mars},
  	\code{polymars},
  	\code{nnet}.

}


\examples{
## regFit -
   xmpSeries("\nStart: Load US Recession Modelling Data Set > ")
   data(recession) 
   
## myPlot -
   xmpSeries("\nNext: Write Internal Plot Function > ")
   myPlot = function(recession, in.sample) {
     Date = recession[, "date"]
     Date = trunc(Date/100) + (Date-100*trunc(Date/100))/12
     Recession = recession[, "recession"]
     inSample = as.vector(in.sample)
     plot(Date, Recession, type = "n", main = "US Recession")
     grid()
     lines(Date, Recession, type = "h", col = "steelblue3")
     lines(Date, inSample) }
   
## Generalized Additive Modelling:
   xmpSeries("\nNext: Generalized Additive Modelling > ")
   par(mfrow = c(2, 2))
   fit = regFit(formula = recession ~ s(tbills3m) + s(tbonds10y),
   	 family = gaussian(), data = recession, method = "GAM")
   # In Sample Prediction:
   in.sample = predict(fit, newdata = recession)$fit  
   myPlot(recession, in.sample)
   # Summary:
   summary(fit)
   # Add plots from the original plot method:
   gam.fit = fit@fit
   class(gam.fit) = "gam"
   plot(gam.fit)
    
## POLYMARS Modelling:
   xmpSeries("\nNext: Polymars Modelling - Mode Parameters> ")
   par(mfrow = c(3, 2), ask = FALSE)
   fit = regFit(formula = recession ~ tbills3m + tbonds10y,
   	 family = gaussian(), data = recession, method = "POLYMARS")
   fit
}


\keyword{models}


\eof
\name{lmTests}

\alias{lmTests}

\alias{lmTest}
\alias{bgTest}
\alias{bpTest}
\alias{dwTest}
\alias{gqTest}
\alias{harvTest}
\alias{hmcTest}
\alias{rainTest}
\alias{resetTest}

\title{Regression Tests}


\description{

	A collection of functions to test linear regression models, including 
	tests for higher serial correlations, for heteroskedasticity, for 
	autocorrelations of disturbances, for linearity, and functional 
	relations.
	\cr
		
	The methods are:
	
	\tabular{rll}{
		1	\tab 	\code{"bg"}	
			\tab  	Breusch--Godfrey test for higher order serial correlation, \cr
		2	\tab 	\code{"bp"}		
			\tab  	Breusch--Pagan test for heteroskedasticity, \cr
		3	\tab 	\code{"dw"} 	
			\tab  	Durbin--Watson test for autocorrelation of disturbances, \cr
		4	\tab 	\code{"gq"} 	
			\tab  	Goldfeld--Quandt test for heteroskedasticity, \cr
		5	\tab 	\code{"harv"} 	
			\tab  	Harvey--Collier test for linearity, \cr
		6	\tab 	\code{"hmc"}	
			\tab  	Harrison--McCabe test for heteroskedasticity, \cr
		7	\tab 	\code{"rain"} 	
			\tab  	Rainbow test for linearity, and \cr
		8	\tab 	\code{"reset"} 	
			\tab  	Ramsey's RESET test for functional relation. }
	
	There is nothing new, it's just a wrapper to the underlying test
	functions from R's contributed package \code{lmtest}. The functions
	are available as "Builtin" functions. Nevertheless, the user can 
	still install and use the original functions from \R's \code{lmtest} 
	package.
	
}


\usage{
lmTest(formula, method = ("bg", "bp", "dw", "gq", "harv", "hmc", 
	"rain", "reset", \dots)
}


\arguments{

  	\item{formula}{
  		a symbolic description for the linear model to be tested.
  		}
  	\item{method}{
  		the test method which should be applied.
  		}
  	\item{\dots}{
  		additional arguments passed to the underlying lm test.
  		}
  	
  	Some of the tests can specify additional optional arguments like for
  	alternative hypothesis, the type of test statistic to be returned,
  	or others. All the optional arguments have default settings. 
  
}


\details{
	
	\bold{bg -- Breusch Godfrey Test:}
	\cr\cr	
	Under \eqn{H_0} the test statistic is asymptotically Chi-squared 
	with degrees of freedom as given in \code{parameter}.
  	If \code{type} is set to \code{"F"} the function returns
  	the exact F statistic which, under \eqn{H_0}, follows an \eqn{F}
  	distribution with degrees of freedom as given in \code{parameter}.
	The starting values for the lagged residuals in the supplementary
  	regression are chosen to be 0.
  	\cr
  	Additional arguments which can be past to the test function are:
  	\cr
  	\code{order = 1} - an integer. The maximal order of serial correlation 
  		to be tested. 
  		\cr
  	\code{type = c("Chisq", "F")} - the type of test statistic to be 
  		returned. Either \code{"Chisq"} for the Chi-squared test statistic 
  		or \code{"F"} for the F test statistic. 
  		\cr
  	\code{[lmtest:bgtest]}
  	\cr
  	
  	
  	\bold{bp -- Breusch Pagan Test:}
  	\cr\cr
  	The Breusch--Pagan test fits a linear regression model to the 
  	residuals of a linear regression model (by default the same 
  	explanatory variables are taken as in the main regression
	model) and rejects if too much of the variance
	is explained by the additional explanatory variables.
	Under \eqn{H_0} the test statistic of the Breusch-Pagan test 
	follows a chi-squared distribution with \code{parameter} 
	(the number of regressors without the constant in the model) 
	degrees of freedom.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
  	\code{varformula = NULL} -  a formula describing only the potential 
  		explanatory variables for the variance, no dependent variable 
  		needed. By default the same explanatory variables are taken 
  		as in the main regression model. 
		\cr
	\code{studentize = TRUE} - a logical value. If set to \code{TRUE} 
		Koenker's studentized version of the test statistic will 
		be used. 
		\cr  	
	\code{[lmtest:bptest]}
	\cr
	
	
	\bold{dw -- Durbin Watson Test:}
	\cr\cr
	The Durbin--Watson test has the null hypothesis that the autocorrelation
	of the disturbances is 0; it can be tested against the alternative 
	that it is greater than, not equal to, or less than 0 respectively. 
	This can be specified by the \code{alternative} argument.
	The null distribution of the Durbin-Watson test statistic is a linear
	combination of chi-squared distributions. The p value is computed using a
	Fortran version of the Applied Statistics Algorithm AS 153 by Farebrother
	(1980, 1984). This algorithm is called "pan" or "gradsol". For large sample
	sizes the algorithm might fail to compute the p value; in that case a 
	warning is printed and an approximate p value will be given; this p 
	value is computed using a normal approximation with mean and variance 
	of the Durbin-Watson test statistic.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
  	\code{alternative = c("greater", "two.sided", "less")} - a 
  		character string specifying the alternative hypothesis. 
  		\cr
  	\code{iterations = 15} - an integer specifying the number of iterations 
  		when calculating the p-value with the "pan" algorithm. 
  		\cr
	\code{exact = NULL} - a logical flag. If set to \code{FALSE} a 
		normal approximation will be used to compute the p value, 
		if \code{TRUE} the "pan" 
		algorithm is used. The default is to use "pan" if the sample size 
		is \code{< 100}. 
		\cr
	\code{tol = 1e-10} - the tolerance value. Eigenvalues computed have to be 
		greater than \code{tol} to be treated as non-zero. 
		\cr	
	\code{[lmtest:dwtest]}
	\cr
	
	
	\bold{gq -- Goldfeld Quandt Test:}
	\cr\cr
	The Goldfeld--Quandt test compares the variances of two submodels
	divided by a specified breakpoint and rejects if the variances differ.
	Under \eqn{H_0} the test statistic of the Goldfeld-Quandt test 
	follows an F distribution with the degrees of freedom as given in 
	\code{parameter}.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
  	\code{point = 0.5} - a numeric value. If point is smaller than 
  		\code{1} it is 
  		interpreted as percentages of data, i.e. \code{n*point} is 
  		taken to be the (potential) breakpoint in the variances, if 
  		\code{n} is the number of observations in the model. If \code{point} 
  		is greater than \code{1} it is interpreted to be the index of 
  		the breakpoint. 
  		\cr
	\code{order.by = NULL} - a formula. A formula with a single explanatory 
		variable like \code{~ x}. Then the observations in the model 
		are ordered by the size of \code{x}. If set to \code{NULL}, 
		the default, the observations are assumed to be 
		ordered (e.g. a time series). 
		\cr
	\code{[lmtest:gqtest]}
	\cr
	
	
	\bold{harv - Harvey Collier Test:}
	\cr\cr
	The Harvey-Collier test performs a t-test (with \code{parameter} 
	degrees of freedom) on the recursive residuals. If the true relationship 
	is not linear but convex or concave the mean of the recursive residuals 
	should differ from 0 significantly.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
  	\code{order.by = NULL} - a formula. A formula with a single explanatory 
		variable like \code{~ x}. Then the observations in the model 
		are ordered by the size of \code{x}. If set to \code{NULL}, 
		the default, the observations are assumed to be 
		ordered (e.g. a time series). 
		\cr
	\code{[lmtest:harvtest]}
	\cr
	
	
	\bold{hmc -- Harrison McCabe Test:}
	\cr\cr	
	The Harrison--McCabe test statistic is the fraction of the residual 
	sum of squares that relates to the fraction of the data before the 
	breakpoint. Under \eqn{H_0} the test statistic should be close to 
	the size of this fraction, e.g. in the default case close to 0.5. 
	The null hypothesis is reject if the statistic is too small.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
  	\code{point = 0.5} - a numeric value. If point is smaller than \code{1} 
  		it is interpreted as percentages of data, i.e. \code{n*point} is 
  		taken to be the (potential) breakpoint in the variances, if 
  		\code{n} is the number of observations in the model. If \code{point} 
  		is greater than \code{1} it is interpreted to be the index of 
  		the breakpoint. 
  		\cr
	\code{order.by = NULL} - a formula. A formula with a single explanatory 
		variable like \code{~ x}. Then the observations in the model 
		are ordered by the size of \code{x}. If set to \code{NULL}, 
		the default, the observations are assumed to be 
		ordered (e.g. a time series). 
		\cr
	\code{simulate.p = TRUE} - a logical. If \code{TRUE} a p value will be 
		assessed by simulation, otherwise the p value is \code{NA}. 
		\cr
	\code{nsim = 1000} - an integer value. Determins how many runs are used 
		to simulate the p value. 
		\cr
	\code{plot = FALSE} - a logical flag. If \code{TRUE} the test statistic 
		for all possible breakpoints is plotted. 
		\cr
	\code{[lmtest:hmctest]}
	\cr
	
	
	\bold{rain -- Rainbow Test:}
	\cr\cr	
	The basic idea of the Rainbow test is that even if the true 
	relationship is non-linear, a good linear fit can be achieved 
	on a subsample in the "middle" of the data. The null hypothesis 
	is rejected whenever the overall fit is significantly inferious 
	to the fit of the subsample. The test statistic under \eqn{H_0} 
	follows an F distribution with \code{parameter} degrees of freedom.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
	\code{fraction = 0.5} - a numeric value. The percentage of observations 
		in the subset is determined by \code{fraction*n} if \code{n} 
		is the number of observations in the model. 
		\cr
	\code{order.by = NULL} -  either a formula or a string. A formula with 
		a single explanatory variable like \code{~ x}. The observations in 
		the model are ordered by the size of \code{x}. If set to 
		\code{NULL}, the default, the observations are assumed to be 
		ordered (e.g. a time series). If set to \code{"mahalanobis"} 
		then the observations are ordered by their Mahalanobis 
		distance of the data. 
		\cr
	\code{center = NULL} - a numeric value. If center is smaller than \code{1} 
		it is interpreted as percentages of data, i.e. the subset 
		is chosen that \code{n*fraction} observations are around 
		observation number \code{n*center}. If center is greater than 
		\code{1} it is interpreted to be the index of the center of 
		the subset. By default center is 0.5. If the Mahalanobis 
		distance is chosen center is taken to be the mean regressor, 
		but can be specified to be a k-dimensional vector if k is the 
		number of regressors and should be in the range of the 
		respective regressors. 
		\cr
	\code{[lmtest:raintest]}
	\cr
	
	
	\bold{reset -- Ramsey's RESET Test}
	\cr\cr	
	RESET test is popular means of diagnostic for correctness of 
	functional form. The basic assumption is that under the alternative, 
	the model can be written by the regression
	\eqn{ y = X\beta + Z\gamma + u}{y=X * beta + Z * gamma}.
	\code{Z} is generated by taking powers either of the fitted response, 
	the regressor variables or the first principal component of \code{X}. 
	A standard F-Test is then applied to determin whether these additional 
	variables have significant influence. The test statistic under 
	\eqn{H_0} follows an F distribution with \code{parameter} degrees 
	of freedom.
	\cr
	Additional arguments which can be past to the test function are:
  	\cr
	\code{power = 2:3} - integers. A vector of positive integers 
		indicating the powers of the variables that should be 
		included. By default it is tested for a quadratic or cubic 
		influence of the fitted response. 
		\cr
	\code{type = c("fitted", "regressor", "princomp")} - a string 
		indicating whether powers of the fitted response, the regressor 
		variables (factors are left out) or the first principal 
		component of the regressor matrix should be included in 
		the extended model. 
		\cr
	\code{[lmtest:reset]}

}


\value{

  	A list with class \code{"htest"} containing the following components:

  	\item{statistic}{
		the value of the test statistic.
		}
  	\item{parameter}{
		the lag order.
		}
  	\item{p.value}{
		the p-value of the test.
		}
  	\item{method}{
		a character string indicating what type of test was
		performed.
		} 
  	\item{data.name}{
		a character string giving the name of the data.
		}
  	\item{alternative}{
		a character string describing the alternative
		hypothesis.
		}
		
}


\notes{

	The underlying \code{lmtest} package comes wit a lot of helpful
	examples. We highly recommend to install the \code{lmtest} package
	and to study the examples given therein.

}


\references{

Breusch, T.S. (1979);
	\emph{Testing for Autocorrelation in Dynamic Linear Models}, 
  	Australian Economic Papers 17, 334--355.
 
Breusch T.S. and Pagan A.R. (1979);
	\emph{A Simple Test for Heteroscedasticity and Random 
	Coefficient Variation},
	Econometrica 47, 1287--1294
	 
Durbin J. and Watson G.S. (1950);
	\emph{Testing for Serial Correlation in Least Squares Regression I},
	Biometrika 37, 409--428.

Durbin J. and Watson G.S. (1951);
	\emph{Testing for Serial Correlation in Least Squares Regression II},
	Biometrika 38, 159--178.

Durbin J. and Watson G.S. (1971);
	\emph{Testing for Serial Correlation in Least Squares Regression III},
	Biometrika 58, 1--19.
	
Farebrother R.W. (1980);
	\emph{Pan's Procedure for the Tail Probabilities of the
	Durbin-Watson Statistic},
	Applied Statistics 29, 224--227.

Farebrother R.W. (1984);
	\emph{The Distribution of a Linear Combination of $\chi^2$ Random
  	Variables},
	Applied Statistics 33, 366--369.

Godfrey, L.G. (1978);
	\emph{Testing Against General Autoregressive and
  	Moving Average Error Models when the Regressors Include Lagged
  	Dependent Variables}, 
  	Econometrica 46, 1293--1302.

Goldfeld S.M. and Quandt R.E. (1965);
	\emph{Some Tests for Homoskedasticity}
	Journal of the American Statistical Association 60, 539--547.
	
Harrison M.J. and McCabe B.P.M. (1979);
	\emph{A Test for Heteroscedasticity based on Ordinary Least 
	Squares Residuals}
	Journal of the American Statistical Association 74, 494--499.

Harvey A. and Collier P. (1977);
	\emph{Testing for Functional Misspecification in Regression 
	Analysis},
	Journal of Econometrics 6, 103--119.
	
Johnston, J. (1984); 
	\emph{Econometric Methods}, 
	Third Edition, McGraw Hill Inc.

Kraemer W. and Sonnberger H. (1986);
	\emph{The Linear Regression Model under Test}, 
	Heidelberg: Physica.
	
Racine J. and Hyndman R. (2002);
	\emph{Using R To Teach Econometrics},
	Journal of Applied Econometrics 17, 175--189.
	
Ramsey J.B. (1969);
	\emph{Tests for Specification Error in Classical Linear Least 
	Squares Regression Analysis},
	Journal of the Royal Statistical Society, Series B 31, 350--371.
	
Utts J.M. (1982);
	\emph{The Rainbow Test for Lack of Fit in Regression},
	Communications in Statistics - Theory and Methods 11, 1801--1815.
	
}


\author{

	Achim Zeileis and Torsten Hothorn for the lmtest package, \cr
	Diethelm Wuertz for this \R-port.
	
}


\seealso{
	
	\code{classicalTests},
	\code{tseriesTests}.
	
}


\examples{
## bg -
   xmpSeries("\nStart: Breusch-Godfrey Test > ")
   # Generate a Stationary and an AR(1) Series
   x = rep(c(1, -1), 50)
   y1 = 1 + x + rnorm(100)
   # Perform Breusch-Godfrey Test 
   ## for first order serial correlation
   lmTest(y1 ~ x, "bg")
   ## or for fourth order serial correlation
   lmTest(y1 ~ x, "bg", order = 4)    
   # Compare with Durbin-Watson Test Results:
   lmTest(y1 ~ x, "dw")
   require(ts)
   y2 = filter(y1, 0.5, method = "recursive")
   lmTest(y2 ~ x, "bg") 
   
## bp -
   xmpSeries("\nStart: Breusch-Pagan Test > ")
   # Generate a Regressor
   x = rep(c(-1, 1), 50)
   # Generate heteroskedastic and homoskedastic Disturbances
   err1 = rnorm(100, sd = rep(c(1, 2), 50))
   err2 = rnorm(100)
   # Generate a Linear Relationship
   y1 = 1 + x + err1
   y2 = 1 + x + err2
   # Perform Breusch-Pagan Test
   bp = lmTest(y1 ~ x, "bp")
   bp
   # Calculate Critical Value for 0.05 Level
   qchisq(0.95, bp$parameter)
   lmTest(y2 ~ x, "bp")
   
## dw -
   xmpSeries("\nNext: Durban-Watson Test > ")
   # Generate two AR(1) Error Terms 
   # with parameter rho = 0 (white noise) 
   # and rho = 0.9 respectively
   err1 = rnorm(100)
   # Generate Regressor and Dependent Variable
   x = rep(c(-1,1), 50)
   y1 = 1 + x + err1
   # Perform Durbin-Watson Test
   lmTest(y1 ~ x, "dw")
   require(ts)
   err2 = filter(err1, 0.9, method = "recursive")
   y2 = 1 + x + err2
   lmTest(y2 ~ x, "dw")
   
## gq -
   xmpSeries("\nNext: Goldfeld-Quandt Test > ")
   # Generate a Regressor
   x = rep(c(-1,1), 50)
   # Generate Heteroskedastic and Homoskedastic Disturbances
   err1 = c(rnorm(50, sd = 1), rnorm(50, sd = 2))
   err2 = rnorm(100)
   # Generate a Linear Relationship
   y1 = 1 + x + err1
   y2 = 1 + x + err2
   # Perform Goldfeld-Quandt Test
   lmTest(y1 ~ x, "gq")
   lmTest(y2 ~ x, "gq")
   
## harv -
   xmpSeries("\nNext: Harvey-Collier Test > ")
   # Generate a Regressor and Dependent Variable
   x = 1:50
   y1 = 1 + x + rnorm(50)
   y2 = y1 + 0.3*x^2
   # Perform Harvey-Collier Test
   harv = lmTest(y1 ~ x, "harv")
   harv
   # Calculate Critical Value vor 0.05 level
   qt(0.95, harv$parameter)
   lmTest(y2 ~ x, "harv")
   
## hmc -
   xmpSeries("\nNext: Harrison-McCabe Test > ")
   # Generate a Regressor
   x = rep(c(-1, 1), 50)
   # Generate Heteroskedastic and Homoskedastic Disturbances
   err1 = c(rnorm(50, sd = 1), rnorm(50, sd = 2))
   err2 = rnorm(100)
   # Generate a Linear Relationship
   y1 = 1 + x + err1
   y2 = 1 + x + err2
   # Perform Harrison-McCabe Test
   lmTest(y1 ~ x, "hmc")
   lmTest(y2 ~ x, "hmc")
   
## rain -
   xmpSeries("\nNext: Rainbow Test > ")
   # Generate Series
   x = c(1:30)
   y = x^2 + rnorm(30, 0, 2)
   # Perform rainbow Test
   rain = lmTest(y ~ x, "rain")
   rain
   # Compute Critical Valuealue
   qf(0.95, rain$parameter[1], rain$parameter[2]) 
   
## reset -
   xmpSeries("\nNext: Reset Test > ")
   # Generate Series
   x = c(1:30)
   y1 = 1 + x + x^2 + rnorm(30)
   y2 = 1 + x + rnorm(30)
   # Perform RESET Test
   lmTest(y1 ~ x , "reset", power = 2, type = "regressor")
   lmTest(y2 ~ x , "reset", power = 2, type = "regressor")          
    
}


\keyword{htest}


\eof
\name{technicalAnalysis}

\alias{technicalAnalysis}

\alias{emaTA}
\alias{biasTA}
\alias{medpriceTA}
\alias{typicalpriceTA}
\alias{wcloseTA}

\alias{rocTA}
\alias{oscTA}
\alias{momTA}
\alias{macdTA}
\alias{cdsTA}

\alias{cdoTA}
\alias{vohlTA}
\alias{vorTA}
\alias{fpkTA}
\alias{fpdTA}

\alias{spdTA}
\alias{apdTA}
\alias{wprTA}
\alias{rsiTA}


\title{Tools for the Technical Analysis}


\description{

	A collection of functions for the technical analysis of stock markets. 
	This collection provides a set of the most common technical indicators 
	together with functions for open--high--close--low charts, and three 
	functions for benchmark measurements.
	\cr
	
	The functions are:
	
	\tabular{rll}{
	 	1	\tab 	\code{emaTA}			
	 		\tab 	Exponential Moving Average, \cr
	 	2	\tab	\code{biasTA}			
	 		\tab 	Bias Indicator, \cr
	 	3	\tab	\code{medpriceTA}		
	 		\tab 	Medium Price Indicator, \cr
	 	4	\tab	\code{typicalpriceTA} 	
	 		\tab 	Typical Price Indicator, \cr
	 	5	\tab	\code{wcloseTA}		
	 		\tab 	Weighted Close Indicator, \cr
	 	6	\tab	\code{rocTA}		
	 		\tab 	Rate of Change, \cr
	 	7	\tab	\code{oscTA}			
	 		\tab 	Oscillator Indicator, \cr
	 	8	\tab	\code{momTA}			
	 		\tab 	Momentum Indicator, \cr
	 	9	\tab	\code{macdTA}			
	 		\tab 	MACD Indicator, \cr
	   10	\tab	\code{cdsTA}		
	   		\tab 	MACD Signal Line, \cr
	   11	\tab	\code{cdoTA}			
	   		\tab 	MACD Oscillator, \cr
	   12	\tab	\code{vohlTA}			
	   		\tab 	High/Low Volatility, \cr
	   13	\tab	\code{vorTA}			
	   		\tab 	Volatility Ratio, \cr
	   14	\tab	\code{fpkTA}		
	   		\tab 	Fast Percent K, \cr
	   15	\tab	\code{fpdTA}			
	   		\tab 	Fast Percent D, \cr
	   16	\tab	\code{spdTA}		
	   		\tab 	Slow Percent D, \cr
	   17	\tab	\code{apdTA}		
	   		\tab 	Averaged Percent D, \cr
	   18	\tab	\code{wprTA}		
	   		\tab 	William's Percent R, \cr
	   19	\tab	\code{rsiTA}		
	   		\tab 	Relative Strength Index. }
	
}


\usage{
emaTA(x, lambda, startup = 0)
biasTA(x, lag)
rocTA(x, lag)
oscTA(x, lag1, lag2)
momTA(x, lag)
macdTA(x, lag1, lag2)
cdsTA(x, lag1, lag2, lag3)
cdoTA(x, lag1, lag2, lag3)
vohlTA(high, low)
vorTA(high, low)
fpkTA(close, high, low, lag)
fpdTA(close, high, low, lag1, lag2)
spdTA(close, high, low, lag1, lag2, lag3)
apdTA(close, high, low, lag1, lag2, lag3, lag4)
wprTA(close, high, low, lag)
rsiTA(close, lag)

medpriceTA(high, low)
typicalpriceTA(high, low, close)
wcloseTA(high, low, close)
}


\arguments{

  	\item{lag, lag1, lag2, lag3, lag4}{
		integer values, time lags.
		}
  	\item{lambda}{
		a numeric value, the decay length of the exponential
		moving average.
		}
	 	\item{startup}{
		an integer value, the startup position of the exponential
		moving average, by default 0.
		}
	\item{x, high, low, close}{
		a numeric vector of prices, either opening, closing, or
		high and low values.
		For \code{ohlcPlot} a multivariate time series object of 
		class \code{mts}.
		}

}


\value{

	\code{*TA}
	\cr	
	The technical Indicators return the following numeric vectors:

	\code{emaTA}  returns the Exponential Moving Average, EMA \cr
	\code{biasTA} returns the EMA-Bias, \cr
	\code{rocTA}  returns the Rate of Change Indicator, \cr
	\code{oscTA}  returns the EMA Oscillator Indicator, \cr
	\code{momTA}  returns the Momentum Oscillator, \cr
	\code{macdTA} returns the MACD Oscillator, \cr
	\code{cdsTA}  returns the MACD Signal Line, \cr
	\code{cdo}    returns the MACD Oscillator, \cr
	\code{vohlTA} returns the High/Low Volatility Oscillator, \cr
	\code{vorTA}  returns Volatility Ratio Oscillator, \cr
	\code{fpkTA}  returns the Fast Percent-K Stochastics Indicator, \cr
	\code{fpdTA}  returns the Fast Percent-D Stochastics Indicator, \cr
	\code{spdTA}  returns the Slow Percent-D Stochastics Indicator, \cr
	\code{apdTA}  returns the Averaged Percent-D Stochastics Indicator, \cr
	\code{wprTA}  returns the Williams Percent-R Stochastics Indicator, \cr
	\code{rsiTA}  returns the Relative Strength Index Stochastics Indicator, \cr
	\code{medpriceTA} returns the Medium Price, \cr
	\code{typicalpriceTA} returns the Typical Price, \cr
	\code{wcloseTA} returns the Weighted Closing Price. \cr

}


\author{

	Diethelm Wuertz for this \R-port.
}


\examples{
## Currently no examples ...
}
   

\keyword{math}


\eof
\name{benchmarkAnalysis}

\alias{benchmarkAnalysis}

\alias{ohlcPlot}

\alias{sharpeRatio}
\alias{sterlingRatio}
\alias{maxDrawDown}

\alias{getReturns}


\title{Utilities and Benchmark Analysis}


\description{

	A collection of untility and benchmark functions for the analysis of 
	financial markets. The collection provides a set of functions for the
	computation of returns, for the display of price charts, and for 
	benchmark measurements.
	\cr
	
	The functions are:
	
	\tabular{rll}{
	   1	\tab	\code{getReturns}		
	   		\tab 	Computes returns given a price series, \cr
	   2	\tab	\code{ohlcPlot}      	
	   		\tab 	Plots open--high--low--close bar charts, \cr
	   3 	\tab 	\code{sharpeRatio}	  	
	   		\tab 	Computes Sharpe Ratio, \cr
	   4 	\tab	\code{sterlingRatio} 	
	   		\tab 	Computes Sterling Ratio, \cr
	   5	\tab	\code{maxDrawDown}	  	
	   		\tab 	Computes maximum drawdown.}
	
}


\usage{
getReturns(x, type = c("continuous", "discrete"), percentage = FALSE, 
	trim = TRUE)
	
ohlcPlot(x, xlim = NULL, ylim = NULL, xlab = "Time", ylab, col = par("col"),
	bg = par("bg"), axes = TRUE, frame.plot = axes, ann = par("ann"),
   	main = NULL, date = c("calendar", "julian"), format = "\%Y-\%m-\%d",
    origin = "1899-12-30", \dots)
    
sharpeRatio(x, r = 0, scale = sqrt(250))
sterlingRatio(x)

maxDrawDown(x)
}


\arguments{
	
  	\item{date, format, origin}{
	    date elements,\cr
	    \code{date}, a string indicating the type of x axis annotation. 
	    Default is calendar dates. \cr
  		\code{format}, a string indicating the format of the x axis 
  		annotation if \code{date == "calendar"}. For details see
	    \code{\link{format.POSIXct}}. \cr
		\code{origin} an R object specifying the origin of the Julian 
		dates if \code{date == "calendar"}. Defaults to 1899-12-30 
		(Popular spreadsheet programs internally also use Julian dates 
		with this origin).
	    }
	\item{percentage}{
  		a logical flag. If set to \code{TRUE}, the return series will 
  		be expressed in percentage points otherwise not. The default 
  		is \code{FALSE}. 
		}
  	\item{r}{
	    the risk free rate. Default corresponds to using portfolio
	    returns not in excess of the riskless return.
	    }
  	\item{scale}{
	    a scale factor. Default corresponds to an annualization
	    when working with daily financial time series data.
	    } 
	\item{trim}{
  		a logical flag. If set to \code{TRUE}, the first missing 
  		observation in the return series will be removed. The 
  		default is \code{TRUE}.
  		}
   	\item{type}{
		a character string specifying the type of returns to be 
		computed. If \code{type="continuous"}, the returns are calculated 
		as the logarithm differences; if \code{type="discrete"}, the 
		returns are calculated as percentage changes.
		} 
	\item{x}{
		a numeric vector of prices.
		For \code{ohlcPlot} a multivariate time series object of 
		class \code{mts} is required.
		}
	\item{xlim, ylim, xlab, ylab, col, bg, axes, frame.plot, ann, main}{
	    graphical arguments, see \code{\link{plot}},
	    \code{\link{plot.default}} and \code{\link{par}}.
	    }		
  	\item{\dots}{
	    further graphical arguments passed to \code{\link{plot.window}}, 
	    \code{\link{title}}, \code{\link{axis}}, and \code{\link{box}}.
	    }	    

}

\details{

	\bold{Open--High--Low--Close Chart:}
	\cr\cr
	Within an open--high--low--close bar chart, each bar represents
    price information for the time interval between the open and the close
  	price. The left tick for each bar indicates the open price for the
  	time interval. The right tick indicates the closing price for the time
  	interval. The vertical length of the bar represents the price range
  	for the time interval.
	The time scale of \code{x} must be in Julian dates (days since the
  	\code{origin}).
  	\cr
  	\code{[tseries:plotOHLC]}
  	\cr
  	
  	\bold{Sharpe and Sterling Ratios:}
  	\cr\cr	
  	The Sharpe ratio is defined as a portfolio's mean return in excess of
  	the riskless return divided by the portfolio's standard deviation. In
  	finance the Sharpe Ratio represents a measure of the portfolio's
  	risk-adjusted (excess) return. 
    The Sterling ratio is defined as a portfolio's overall return divided
    by the portfolio's maximum drawdown statistic. In finance the
   	Sterling Ratio represents a measure of the portfolio's risk-adjusted
   	return.
   	\cr
   	\code{[tseries:sharpe]}
   	\cr  
   	
   	\bold{Maximum Drawdown:}
   	\cr\cr
	The maximum drawdown or maximum loss statistic is defined as the 
	maximum value drop after one of the peaks of \code{x}. For financial
  	instruments the maximum drawdown represents the worst investment 
  	loss for a buy--and--hold strategy invested in \code{x}.
  	\cr
  	\code{[tseries:maxdrawdown]}
  	\cr
  	
  	\bold{Get Returns:}
  	\cr\cr
  	The function computes the return series given a financial security 
  	price series. The price series may be an object of class \code{numeric}
  	or a time series object. This includes objects of classes \code{"ts"},
  	\code{"its"} and/or \code{"timeSeries"}.
  	
}


\value{

	\code{ohlcPlot} 
	\cr
	creates an Open--High--Low--Close chart.
	
	\code{sharpeRatio}\cr
	\code{sterlingRatio} 
	\cr
	return the Sharpe or Sterling ratio, a numeric value.
	
	\code{maxDrawDown}
	\cr
	returns a list containing the following three components: 
	\code{maxDrawDown}, double representing the max drawdown or max loss 
	statistic; \code{from}, the index (or vector of indices) where the 
	maximum drawdown period starts; \code{to}, the index (or vector of 
	indices) where the max drawdown period ends.
	
	\code{getReturns}
	\cr
	returns an object of the same class as the input object \code{x}.

}


\author{

	Adrian Trapletti for the ohlcPlot,*Ratio and maxDrawDown functions, \cr
	Diethelm Wuertz for this \R-port.
	
}


\examples{
## ohlcPlot -
   # Plot OHLC for SP500
   # ohlcPlot(x, ylab = "price", main = instrument)
   
## sharpeRatio -
   xmpSeries("\nStart: Sharpe Ratio > ")
   # Sharpe Ratio for DAX and FTSE:
   data(EuStockMarkets)
   dax = log(EuStockMarkets[, "DAX"])
   ftse = log(EuStockMarkets[, "FTSE"])
   # Ratios:
   sharpeRatio(dax)
   sharpeRatio(ftse)
   
## maxDrawDown -
   xmpSeries("\nNext: Max-Draw-Downs for the DAX Index >")
   par(mfrow = c(1, 1))
   data(EuStockMarkets)
   dax = log(EuStockMarkets[, "DAX"])
   mdd = maxDrawDown(dax)
   mdd
   # Plot DAX:
   plot(dax)
   segments(time(dax)[mdd$from], dax[mdd$from],
     time(dax)[mdd$to], dax[mdd$from], col = "grey")
   segments(time(dax)[mdd$from], dax[mdd$to],
     time(dax)[mdd$to], dax[mdd$to], col = "grey")
   mid = time(dax)[(mdd$from + mdd$to)/2]
   arrows(mid, dax[mdd$from], mid, dax[mdd$to], col = "red", length = 0.16)
   title(main = "DAX: Max Drawdown")
   
## getReturns -
   xmpSeries("\nNext: Returns for the DAX Index >")
   par(mfrow = c(1, 1))
   data(EuStockMarkets)
   dax = log(EuStockMarkets[, "DAX"])
   plot(getReturns(dax))
   title(main = "DAX: Returns")
}
  

\keyword{math}


\eof
\name{rollingAnalysis}

\alias{rollingAnalysis}

\alias{rollFun}
\alias{rollMin}
\alias{rollMax}
\alias{rollMean}
\alias{rollVar}

\title{Rolling Analysis}


\description{

	A collection of functions to perform a rolling analysis.
	A rolling analysis is often required in building trading models.
		
	The functions are:
	
	\tabular{rll}{
		1  	\tab	\code{rollFun}		
			\tab	Rolling or moving sample statistics, \cr
		2  	\tab	\code{rollMin}		
			\tab	Rolling or moving sample minimum, \cr
		3  	\tab	\code{rollMax}		
			\tab	Rolling or moving sample maximum, \cr
		4  	\tab	\code{rollMean}	
			\tab	Rolling or moving sample mean, \cr
		5  	\tab	\code{rollVar}		
			\tab	Rolling or moving sample variance. }
			
}


\usage{
rollFun(x, n, FUN, ...)
rollMin(x, n = 9, trim = TRUE, na.rm = FALSE) 
rollMax(x, n = 9, trim = TRUE, na.rm = FALSE)
rollMean(x, n = 9, trim = TRUE, na.rm = FALSE)
rollVar(x, n = 9, trim = TRUE, unbiased = TRUE, na.rm = FALSE)
}


\arguments{

  	\item{FUN}{
    	the rolling function, arguments to this function can be
    	passed through the \code{\dots} argument.
    	}
  	\item{n}{
  		an integer specifying the number of periods or 
  		terms to use in each rolling/moving sample.
  		}
  	\item{na.rm}{
  		a logical flag: if TRUE, missing values in x will be removed 
  		before computation. The default is FALSE.
  		}
  	\item{trim}{
    	a logical flag: if TRUE, the first n-1 missing values in 
    	the returned object will be removed; if FALSE, they will 
    	be saved in the returned object. The default is TRUE.
    	}
    \item{unbiased}{
    	a logical flag. If TRUE, the unbiased sample variance 
    	will be returned. The default is TRUE.
    	}
  	\item{x}{
  		a numeric vector or univariate time series.
  		}
  	\item{\dots}{
  		additional arguments to be passed.
  		}
  	
}


\value{

  	The functions return a numeric vector or time series object.
  	
  	\code{rollMax} returns the rolling sample maximum, \cr 
  	\code{rollMin} returns the rolling sample minimum, \cr
  	\code{rollMean} returns the rolling sample mean, and \cr
  	\code{rollVar} returns the biased/unbiased rolling sample variance. 
  	
  	If you like to operate for \code{x} with rectangular objects, 
  	you have to call the functions columnwise within a loop.

}


\author{

	Diethelm Wuertz for this \R-port.
}


\seealso{

	\code{\link{var}}.
	
}


\examples{
## Example:
   xmpSeries("\nNext: Rolling Analysis > ")
   x = (1:10)^2
   x
   trim =  c(TRUE, TRUE, FALSE, FALSE)
   na.rm = c(TRUE, FALSE, TRUE, FALSE)
   for (i in 1:4) 
     print(rollMin(x, 5, trim[i], na.rm[i]))
   for (i in 1:4) 
     print(rollMax(x, 5, trim[i], na.rm[i]))
   for (i in 1:4) 
     print(rollVar(x, 5, trim[i], unbiased = TRUE, na.rm[i]))
   for (i in 1:4) 
     print(rollVar(x, 5, trim[i], unbiased = FALSE, na.rm[i]))
}


\keyword{math}


\eof
\name{fSeriesData}

\alias{fSeriesData}

\alias{nyseres}
\alias{recession}
\alias{spc1970}
\alias{spcindis}

\alias{dem2gbp}
\alias{cac40}


\title{fSeries Data Sets} 


\description{

    A collection of Data Sets used in the examples of the \code{fSeries}
	library.
	\cr
  
  	\code{recession}
  	\cr
  	Data sets used in the regression analysis.
  	Recession data from the US,
  	3 Month Tbills data from US FED,
  	10 Year Tbonds data from US FED,
  	Stock-Watson experimental recession index.
  	\cr	
  	
  	\code{spc1970} and 
  	\code{spcindis}
  	\cr
  	These data are indicators for daily SP500 Stock Data together
  	with an set of trading indicators for technical analysis.
  	\cr
  	
  	\code{dem2gbp}
  	\cr
  	The file "dem2gbp" contains daily observations of the 
	Deutschmark / British Pound foreign exchange log returns. 
	This data set has been promoted as an informal benchmark 
	for GARCH time-series software validation. See McCullough and 
	Renfro [1991], and Brooks, Burke, and Persand (2001) for details.
	The nominal returns are expressed in percent, as published in 
	Bollerslev and Ghysels (2001). The data set is available from 
	the \emph{Journal of Business and Economic Statistics}, (JBES), 
	\emph{ftp://www.amstat.org}. A text file has one column of 
	data listing the percentual log-returns of the DEM/GBP exchange 
	rates. The sample period is from January 3, 1984, to December 
	31, 1991, for a total of 1975 daily observations of FX exchange 
	rates.
	
	\code{cac40}
	\cr
	Daily CAC40 index returns with realized volatility. The data 
	cover the period January 1995 until December 1999, and have 1249 
	observations. The first column of the file \code{CAC40} lists 
	the averaged return of the Index, and the second column 
	\code{CAC40VOL} lists the realized volatility. The data are
	used a s a benchmark for GARCH modeling by Laurent and Peters
	(2002).
 
}


\format{
	
    All files are in CSV Excel spreadsheet format. 
    
}


\references{

Brooks C., Burke S.P, Persand G. (2001);
	\emph{Benchmarks and the Accuracy of GARCH Model Estimation},
	International Journal of Forecasting 17, 45--56.

McCullough B.D., Renfro C.G. (1998);
	\emph{Benchmarks and Software Standards: A Case Study of GARCH 
	Procedures},
	Journal of Economic and Social Measurement 25, 59--71. 
	
Laurent S., Peters J.P. (2002), 
	\emph{G@RCH 2.2: An Ox Package for Estimating and Forecasting  
	Various ARCH Models}, 
	Journal of Economic Surveys 16, 447--485. 

}


\examples{
## NYSE Residuals:
   data(nyseres)
   ts.plot(nyseres, xlab = "Index", ylab = "log-Returns",
   	 main = "NYSE: log-Returns")
} 
 
 
\keyword{datasets}


\eof
\name{fSeriesMills}

\alias{fSeriesMills}


\alias{RS} 	
\alias{R20} 	
\alias{RSQ} 	
\alias{R20Q} 	
\alias{RSQREAL} 	
\alias{FTAPRICE} 
\alias{FTADIV} 	
\alias{FTARET} 	
\alias{RPI} 	
\alias{EXCHD} 	
\alias{EXCHQ} 	
\alias{SP500} 	
\alias{SP500R} 	
\alias{SP500D} 	
\alias{FT30} 	
\alias{FTSE100} 	
\alias{CTLD} 	
\alias{LGEN} 	
\alias{PRU} 	
	 		

\title{Terence Mill's Data Sets}


\description{

	A collection of data sets from the book "The Econometric Modelling
	of Financial Time Series" written by Terence C. Mills.
	\cr
	
	The data sets are:
	
	\tabular{rll}{	
	 	 1	\tab	\code{RS.txt} 	
	 		\tab 	Monthly 91 day Treasury Bill rate, \cr
	 	 2	\tab	\code{R20.txt} 	
	 		\tab 	Monthly Yield on 20 Year UK Gilts, \cr
     	 3	\tab	\code{RSQ.txt} 	
     		\tab 	Quarterly 91 day Treasury Bill rate, \cr
     	 4	\tab	\code{R20Q.txt} 	
     		\tab 	Quarterly Yield on 20 Year UK Gilts, \cr
     	 5	\tab	\code{RSQREAL.txt} 	
     		\tab 	Quarterly real 91 day Treasury Bill rate, \cr
     	 6	\tab	\code{FTAPRICE.txt} 
     		\tab	FTA All Share Price Index, \cr
     	 7	\tab	\code{FTADIV.txt} 	
	 		\tab 	FTA All Share Dividend Index, \cr
	 	 8	\tab	\code{FTARET.txt} 	
	 		\tab 	FTA All Share Nominal Returns, \cr
	 	 9	\tab	\code{RPI.txt} 	
	 		\tab 	UK Retail Price Index, \cr
	 	10	\tab	\code{EXCHD.txt} 	
	 		\tab 	Dollar/Sterling Exchange Rate, \cr
	 	11	\tab	\code{EXCHQ.txt} 	
	 		\tab 	Dollar/Sterling Exchange Rate, \cr
	 	12	\tab	\code{SP500.txt} 	
	 		\tab 	SP 500 Annual Data Index, \cr
	 	13	\tab	\code{SP500R.txt} 	
	 		\tab 	SP 500 Real Returns, \cr
	 	14	\tab	\code{SP500D.txt} 	
	 		\tab 	SP 500 Daily Data Index, \cr
	 	15	\tab	\code{FT30.txt} 	
	 		\tab 	FT 30 Index, \cr
	 	16	\tab	\code{FTSE100.txt} 	
	 		\tab 	FTSE 100 Index, \cr
	 	17	\tab	\code{CTLD.txt} 	
	 		\tab 	Courtaulds Share Price, \cr
	 	18	\tab	\code{LGEN.txt} 	
	 		\tab 	Legal and General Share Price, \cr
	 	19	\tab	\code{PRU.txt} 	
	 		\tab 	Prudential Share Price. }
    
}


\details{
     		
    \bold{RS - 91 Day Treasury Bill Rate:}
    \cr\cr
    Monthly data values starting in March 1952 and ending December 1995. 
	The data set includes one column with 526 observations.
	\cr
		
	\bold{R20 - Yield on 20 Year UK Gilts:}
    \cr\cr
    Monthly data values starting in March 1952 and ending December 1995. 
	The data set includes one column with 526 observations.
	\cr
	
	\bold{RSQ - 91 day Treasury Bill Rate:}
    \cr\cr
    Quarterly data values starting in Q1 1952 and ending Q4 1995.
	The data set includes one column with 176 observations.
	\cr
	
	\bold{R20Q - Yield on 20 Year UK Gilts:}
    \cr\cr
    Quarterly data values starting in Q1 1952 and ending Q4 1995.
	The data set includes one column with 176 observations. 
	\cr
	
	\bold{RSQREAL - Real 91 day Treasury Bill Rate:}
    \cr\cr
    Quarterly data values starting in Q1 1952 and ending Q3 1995.
	The data set includes one column with 175 observations.
	\cr
	
	\bold{FTAPRICE - FTA All Share Price Index:}
    \cr\cr
    Monthly data values starting in January 1965 and ending December 1995. 
	The data set includes one column with 372 observations. 
	\cr
	
	\bold{FTADIV - FTA All Share Dividend Index:}
    \cr\cr
    Monthly data values starting in January 1965 and ending December 1995. 
	The data set includes one column with 372 observations.
	\cr
	
	\bold{FTARET - FTA All Share Nominal Returns:}
    \cr\cr
    Monthly data values starting in January 1965 and ending December 1995. 
	The data set includes one column with 372 observations.
	\cr
	
	\bold{RPI - UK Retail Price Index:}
    \cr\cr
    Monthly data values starting in January 1965 and ending December 1995. 
	The data set includes one column with 372 observations.
	\cr
	
	\bold{EXCHD - Dollar/Sterling Exchange Rate:}
    \cr\cr
    Daily data values ranging from 1974 to 1994 
	The data set includes one column with 5'192 observations.
	\cr
	
	\bold{EXCHQ - Dollar/Sterling Exchange Rate:}
    \cr\cr
    Quarterly data values starting in Q1 1972 and ending Q4 1996.
	The data set includes one column with 100 observations.
	\cr
	
	\bold{SP500 - SP 500 Index:}
    \cr\cr
    Annual data values ranging from 1871 to 1997. 
	The data set includes one column with 127 observations.
	\cr
	
	\bold{SP500R - SP 500 Real Returns:}
    \cr\cr
    Annual data values ranging from 1872 to 1995. 
	The data set includes one column with 124 observations.
	\cr
	
	\bold{SP500D - SP 500 Index:}
    \cr\cr
    Daily data values ranging from 1928 to 1991.
	The data set includes one column with 17'054 observations.
	\cr
	
	\bold{FT30 - FT 30 Index:}
    \cr\cr
    Daily data values ranging from 1935 to 1994. 
	The data set includes one column with 15'003 observations.
	\cr
	
	\bold{FTSE100 - FTSE 100 Index:}
    \cr\cr
    Weekly data values ranging from 1984 to 1993.
	The data set includes one column with 521 observations.
	\cr
	
	\bold{CTLD - Courtaulds Share Price:}
    \cr\cr
    Weekly data values ranging from 1984 to 1993.
	The data set includes one column with 521 observations.
	\cr
	
	\bold{LGEN - Legal and General Share Price:}
    \cr\cr
    Weekly data values ranging from 1984 to 1993.
	The data set includes one column with 521 observations.
	\cr
	
	\bold{PRU - Prudential Share Price:}
    \cr\cr
    Weekly data values ranging from 1984 to 1993.
	The data set includes one column with 521 observations.

}

\references{

Mills, T.C. (1999);
	\emph{The Econometric Modelling of Financial Time Series,}
	Second Edition, Cmbridge University Press.
	
}


\examples{
## RS.txt - 
   data(RS)
   plot(as.ts(RS))
}


\keyword{datasets}


\eof
\name{matrixAddon}

\alias{matrixAddon}

\alias{triang}
\alias{Triang}
\alias{pascal}
\alias{colVec}
\alias{rowVec}
\alias{colIds}
\alias{rowIds}
\alias{colIds<-}
\alias{rowIds<-}

\alias{inv}
\alias{norm}
\alias{rk}
\alias{tr}
\alias{kron}

\title{Matrix Arithmetics and Linear Algebra}


\description{
    
    This help page summarizes selected functions available under R for
    matrix arithmetics and linear algebra. Addititionally functions
    are documented which have been added by Rmetrics.
    
    The origin of the functions is marked in the following way:
    R: part of R's base packages, 
    B: part of Rmetrics' fBasics package,
    S: part of this Rmetrics package, fSeries.
    
    The functions are listed by topic.
    \cr
 
    
    \tabular{rll}{  
    
    		\tab	
			\tab	\bold{General Matrix Functions:} \cr
			
     
    	1   \tab    \code{matrix}   
            \tab    Creates a matrix from the given set of values, \cr
        2   \tab    \code{diag}  
            \tab    R: Creates a diagonal matrix or extracts diagonals, \cr
        3   \tab    \code{triang} 
            \tab    S: Extracs the lower tridiagonal part from a matrix, \cr
        4   \tab    \code{Triang}    
            \tab    S: Extracs the upper tridiagonal part from a matrix, \cr
        5   \tab    \code{pascal}  
            \tab    S: Creates a Pascal matrix, \cr
        6   \tab    \code{colVec}   
            \tab    S: Creates a column vector from a vector, \cr
        7   \tab    \code{rowVec}  
            \tab    S: Creates a row vector from a vector, \cr
        8   \tab    \code{as.matrix}   
            \tab    R: Attempts to turn its argument into a matrix, \cr
        9   \tab    \code{is.matrix}   
            \tab    R: Tests if its argument is a (strict) matrix, \cr
        10  \tab    \code{dimnames}   
            \tab    R: Retrieves or sets the dimnames of an object, \cr
        11  \tab    \code{colnames}, \code{rownames}   
            \tab    R: Retrieves or sets the row or column names, \cr   
        12  \tab    \code{colIds}, \code{rowIds}   
            \tab    R: ... use alternatively, \cr
    
    		\tab	
			\tab	\bold{Simple Matrix Operations:} \cr
			
    	1   \tab    \code{dim}   
            \tab    R: Returns the dimension of a matrix object, \cr
        2   \tab    \code{ncol}, \code{nrow}   
            \tab    R: Counts columns|rows of a matrix object, \cr 
        3   \tab    \code{length}   
            \tab    R: Counts elements of a matrix object, \cr 
        4   \tab    \code{"["}, \code{"[["}   
            \tab    R: Subsets a matrix object, \cr
        5   \tab    \code{cbind}, \code{rbind}   
            \tab    R: Augments a matrix object by columns|rows, \cr   

    		\tab	
			\tab	\bold{Basic Statistical Functions:} \cr
			
    	1   \tab    \code{var}   
            \tab    R: Returns the variance matrix, \cr
        2   \tab    \code{cov}  
            \tab    R: Returns the covariance matrix, \cr 
        3   \tab    \code{colStats}, \code{rowStats} 
            \tab    B: Calculates column|row statistics, \cr
        4   \tab    \code{colMeans}, \code{rowMeans}   
            \tab    B: Calculates column|row means, \cr 
        5   \tab    \code{colAvgs}, \code{rowAvgs}   
            \tab    B: Calculates column|row averages, \cr
        6   \tab    \code{colVars}, \code{rowVars}   
            \tab    B: Calculates column|row variances, \cr 
        7   \tab    \code{colStdevs}, \code{rowStdevs}   
            \tab    B: Calculates column|row standard deviations, \cr
        8   \tab    \code{colSkewness}, \code{rowSkewness}  
            \tab    B: Calculates column|row skewness, \cr
        9   \tab    \code{colKurtosis}, \code{rowKurtosis}   
            \tab    B: Calculates column|row kurtosis, \cr 
        10  \tab    \code{colCumsums}, \code{rowCumsums} 
            \tab    B: Calculates column|row cumulated sums, \cr  
            
			\tab	
			\tab	\bold{Linear Algebra:} \cr
			
    	1   \tab    \code{\%*\%}
            \tab    R: Returns the product of two matrices, \cr
        2   \tab    \code{\%x\%}, \code{kron}
            \tab    R: Returns the Kronecker product, \cr 
        3   \tab    \code{det}   
            \tab    R: Returns the determinante of a matrix, \cr
        4   \tab    \code{inv} 
            \tab    S: Returns the inverse of a matrix, \cr
        5   \tab    \code{norm} 
            \tab    S: Returns the norm of a matrix, \cr 
        6   \tab    \code{rk} 
            \tab    S: Returns the rank of a matrix, \cr
        7   \tab    \code{tr} 
            \tab    S: Returns trace of a matrix, \cr 
        8   \tab    \code{t} 
            \tab    R: Returns the transposed matrix, \cr
	
			\tab	
			\tab	\bold{More Linear Algebra:} \cr
	
    	1   \tab    \code{chol}   
            \tab    R: Returns the Cholesky factor matrix, \cr
        2   \tab    \code{eigen}  
            \tab    R: Returns eigenvalues and eigenvectors, \cr 
        3   \tab    \code{svd}
            \tab    R: Returns the singular value decomposition, \cr
        4   \tab    \code{kappa} 
            \tab    R: Returns the condition number of a matrix, \cr 
        5   \tab    \code{qr}
            \tab    R: Returns the QR decomposition of a matrix, \cr
        6   \tab    \code{solve} 
            \tab    R: Solves a system of linear equations, \cr
        7   \tab    \code{backsolve} 
            \tab    R: ... use when the matrix is upper triangular, \cr
        8   \tab    \code{forwardsolve}
            \tab    R: ... use when the matrix is lower triangular. }  

}


\usage{
triang(x)
Triang(x)
pascal(n)

colVec(x)
rowVec(x)
colIds(x, \dots)
rowIds(x, \dots)

inv(x)
norm(x, p = 2)
rk(x, method = c("qr", "chol"))
tr(x)
kron(x, y)
}


\arguments{

	\item{method}{
	 	[rk] - \cr
	 	a character value, the dimension of the square matrix. One can
	 	choose from two methods: For \code{method = "qr"} the rank is
	 	computed as \code{qr(x)$rank}, or alternatively for 
	 	\code{method = "chol"} the rank is
	 	computed as \code{attr(chol(x, pivot = TRUE), "rank")}.
	 	}
	 \item{n}{
	 	[pascal] - \cr
	 	an integer value, the dimension of the square matrix
	 	}
	\item{p}{
	 	[norm] - \cr
	 	an integer value, \code{1}, \code{2} or \code{Inf}.
	 	\code{p=1} - The maximum absolute column sum norm which is defined 
		as the maximum of the sum of the absolute valued elements of columns 
		of the matrix.
		\code{p=2} - The spectral norm is "the norm" of a matrix \code{X}. 
		This value is computed as the square root of the maximum eigenvalue 
		of \code{CX} where \code{C} is the conjugate transpose.
		\code{p=Inf} - The maximum absolute row sum norm is defined 
		as the maximum of the sum of the absolute valued elements
		of rows of the matrix.
	 	}
	\item{x, y}{
		a numeric matrix.
		}
	\item{\dots}{
		arguments to be passed.
		}
}


\details{

	\bold{Function from R's Base Package:}
	\cr\cr
	Most of the functions are described in their R help pages which we
	recommend to consult for further information. For the additiotnal 
	functions added by Rmetrics we give a brief introduction.
	\cr
	
	
	\bold{General Functions:}
	\cr
	
	Functions to generate matrices and related functions are described 
	in the help page \code{\link{matrix}}. To "decorate" these objects 
	several naming functions are available, a description can be found 
	on the help pages \code{\link{dimnames}} and \code{\link{rownames}}.
	\cr
	
	The function \code{pascal} generates a Pascal matrix of order \code{n} 
	which is a symmetric, positive, definite matrix with integer entries 
	made up from Pascal's triangle. The determinant of a Pascal matrix is 1. 
	The inverse of a Pascal matrix has integer entries. If \code{lambda} 
	is an eigenvalue of a Pascal matrix, then \code{1/lambda} is also an 
	eigenvalue of the matrix. Pascal matrices are ill-conditioned. 
	\cr
	
	The functions \code{triang} and \code{Triang} allow to transform a
	square matrix to a lower or upper triangular form. 
	A triangular matrix is either an upper triangular matrix or lower 
	triangular matrix. For the first case all matrix elements \code{a[i,j]}
	of matrix \code{A} are zero for \code{i>j}, whereas in the second case
	we have just the opposite situation. A lower triangular matrix is 
	sometimes also called left triangular. In fact, triangular matrices 
	are so useful that much computational linear algebra begins with 
	factoring or decomposing a general matrix or matrices into triangular 
	form. Some matrix factorization methods are the Cholesky factorization 
	and the LU-factorization. Even including the factorization step, 
	enough later operations are typically avoided to yield an overall 
	time savings. Triangular matrices have the following properties: the 
	inverse of a triangular matrix is a triangular matrix, the product of 
	two triangular matrices is a triangular matrix, the determinant of a 
	triangular matrix is the product of the diagonal elements, the 
	eigenvalues of a triangular matrix are the diagonal elements.
	\cr
	
	The functions \code{colVec} and \code{rowVec} transform a vector into 
	a column and row vector, respectively. A column vector is a matrix 
	object with one column, and a row vector is a matrix object with one row.
	\cr
	
	The functions \code{dimnames}, \code{colname}, and \code{rowname}
	can be used to retrieve and set the names of matrices. The functions 
	\code{rowIds}, \code{colIds}, are S-Plus like synonyms.
	\cr
	
	
	\bold{Simple Matrix Operations:}
	\cr
	
	The functions \code{\link{dim}}, \code{\link{nrow}} and 
	\code{\link{ncol}} are functions to extract the dimension and  
	the number of rows and columns of a matrix. 
	\cr
	
	The usual arithmetic operators, logical operators and mathematical 
	functions like \code{sqrt} or \code{exp} and \code{log}
	operate on matrices element by element. Note, that \code{"*"}
	is not matrix multiplication, instead we have to use \code{"\%*\%"}.
	\cr
	
	The methods \code{"["} and \code{"[["} are suited to extract
	subsets from a matrix, to delete rows and columns, or to permute
	rows and columns. 
	\cr
	
	
	\bold{Basic Statistical Functions:}
	\cr
	
	The functions \code{var} and \code{cov} compute the variance and
	covariance of a matrix.
	\cr
	
	Beside these functions \code{\link{colMeans}} and \code{\link{rowMeans}} 
	are R functions which compute the mean of columns and rows of a matrix. 
	Rmetrics has added further functions to compute column- or rowwise 
	variances, standard deviations, skewness, kurtosis and cumulated sums. 
	Two general  functions named \code{rowStats} and 
	\code{colStats} allow to apply through the argument list any 
	function to compute row and column statistics from matrices.
	\cr
	
	
	\code{Linear Algebra:}
	\cr
	
	Matrix multiplication is done using the operator \code{\%*\%}. 
	\cr
	
	The \emph{Kronecker product} can be computed using the operator 
	\code{\%x\%} or alternatively using the function \code{kron}.
	\cr

	The function \code{det} computes the determinant of a matrix.
	\cr
	
	The inverse of a square matrix \code{inv(X)} of dimension
	\code{n} is defined so that 
	\code{X \%*\% inv(X) = inv(X) \%*\% X = diag(n)} where
	the matrix \code{diag(n)} is the \code{n}-dimensional identity matrix.
	A precondition for the existence of the matrix inverse is that the
	determinant of the matrix \code{det(X)} is nonzero. 
	\cr

	The function \code{t} computes the transposed of a square matrix.
	\cr
	
	The function \code{tr} computes the trace of a square matrix which
	is the sum of the diagonal elements of the matrix under consideration.
	\cr
	
	The function \code{rk} computes the rank of a matrix which is 
	the dimension of the range of the matrix corresponding to the number 
	of linearly independent rows or columns of the matrix, or to the 
	number of nonzero singular values. The rank of a matrix is also
	named inear map. 
	\cr
	
	The function \code{norm} computes the norm of a matrix. Three choices 
	are possible: 
	\code{p=1} - The maximum absolute column sum norm which is defined 
	as the maximum of the sum of the absolute valued elements of columns 
	of the matrix.
	\code{p=2} - The spectral norm is "the norm" of a matrix \code{X}. 
	This value is computed as the square root of the maximum eigenvalue 
	of \code{CX} where \code{C} is the conjugate transpose.
	\code{p=Inf} - The maximum absolute row sum norm is defined 
	as the maximum of the sum of the absolute valued elements
	of rows of the matrix.
	\cr
	

	\code{More Linear Algebra:}
	\cr
	
	The function \code{chol} returns the Cholesky factor matrix,
	\code{eigen} returns eigenvalues and eigenvectors,
	\code{svd} returns the singular value decomposition,
	\code{kappa} estimate the condition number of a matrix,
	\code{qr} returns the QR decomposition of a matrix,
	\code{ginv} returns the Moore-Penrose generalized inverse,
	\code{solve} solves a system of linear equations, use
	\code{backsolve} when the matrix is upper triangular, and
	\code{forwardsolve} when the matrix is lower triangular.
	 
}


\references{

Higham N.J., (2002);
	\emph{Accuracy and Stability of Numerical Algorithms}, 
	2nd ed., SIAM.

Golub, van Loan, (1996);
	\emph{Matrix Computations}, 
	3rd edition. Johns Hopkins University Press. 
}


\examples{
## Examples:

## Create Pascal Matrix:
   xmpSeries("\nStart: Pascal Matrix > ")
   P = pascal(3)
   P
   # Create lower triangle matrix
   L = triang(P)
   L
   # Extract diagonal part
   diag(P)
   
## Add/Subtract/Multiply/Divide:  
   xmpSeries("\nNext: Math Operations > ")
   X = P
   # Multiply matrix with a constant
   3 * X
   # Multiply two matrices elementwise
   X * P                     
   # Multiplies rows/columns of a matrix by a vector
   X \%*\% diag(P)            
   diag(P) \%*\% X           
       
## Operate on Subsets of a Matrix:
   xmpSeries("\nNext: Matrix Subsets > ")
   n = 3; i = 2; j = 3
   D = diag(1:3)
   # Return the dimension of a matrix
   dim(P)                         
   # Get the last colum of a matrix
   P[, ncol(P)]                   
   # Delete a column of a matrix
   P[, -i]                      
   # Permute the columns of a matrix
   P[c(3, 1, 2), ]              
   # Augments matrix horizontally 
   cbind(P, D)                           
      
## Apply a function to all Elements of a Matrix: 
   xmpSeries("\nNext: Operate Element by Element > ")
   # Return square root for each element
   sqrt(P)
   # Exponentiate the matrix elementwise
   exp(P)
   # Compute the median of each column
   apply(P, 2, "median") 
   # Test on all elements of a matrix       
   all( P > 2 )   
   # test on any element in a matrix                
   any( P > 2 )                  
     
## More Matrix Operations:
   xmpSeries("\nNext: More Matrix Operations > ")
   # Return the product of two matrices
   P \%*\% D   
   # Return the Kronecker Product                     
   P \%x\% D                        
   # Return the transposed matrix
   t(P)                           
   # Return the inverse of a matrix
   inv(P)  
   # Return the norm of a matrix                      
   norm(P)                        
   # Return the determinante of a matrix
   det(P)                         
   # Return the rank of a matrix
   rk(P)                            
   # Return trace of a matrix
   tr(P)                          
   # Return the variance matrix
   var(P)     
   # Return the covariance matrix                   
   cov(P)                         
    
## More Linear Algebra:
   xmpSeries("\nNext: Linear Algebra > ")
   X = P; b = c(1, 2, 3)
   # Return the Cholesky factor matrix
   chol(X)                        
   # Return eigenvalues and eigenvectors
   eigen(X)                       
   # Return the singular value decomposition
   svd(X)                         
   # Return the condition number of a matrix
   kappa(X)                       
   # Return the QR decomposition of a matrix
   qr(X)                          
   # Solve a system of linear equations
   # ... use backsolve when the matrix is upper triangular
   # ... use forwardsolve when the matrix is lower triangular
   solve(X, b)  
   backsolve(Triang(X), b)
   solve(Triang(X), b)                 
   forwardsolve(triang(X), b) 
   solve(triang(X), b)                                        
}


\author{

    Diethelm Wuertz for the addons of this R-port.
    
}


\keyword{math}


\eof
\name{Heaviside}

\alias{Heaviside}

\alias{H}
\alias{Sign}
\alias{Delta}
\alias{Boxcar}
\alias{Ramp}


\title{Haviside and Related Functions}


\description{

	This is a collection of functions which compute the Haeviside
	and related functions.
	
	The functions are:
	
	\tabular{rll}{
		1 	\tab 	\code{H}  	
			\tab  	Computes Heaviside unit step function, \cr
		2	\tab 	\code{Sign} 
			\tab  	Just another signum function \cr
		3 	\tab 	\code{Delta}  	
			\tab  	Computes delta function, \cr
		4	\tab 	\code{Boxcar} 
			\tab  	Computes boxcar function, \cr
		5	\tab 	\code{Ramp} 
			\tab  	Computes ramp function. }
			
}


\usage{
H(x, a = 0)
Sign(x, a = 0)
Delta(x, a = 0)
Boxcar(x, a = 0.5)
Ramp(x, a = 0)
}


\arguments{
 	 
  	\item{a}{
		a numeric value, the location of the break.\cr
		}
  	\item{x}{
		a numeric vector.
		}
}


\details{
  
	The Heaviside step function \code{H} is 1 for \code{x>a}, 
	\code{1/2} for \code{x=a}, and \code{0} for \code{x<a}.
	\cr
	The Sign function \code{Sign} is \code{1} for \code{x>a}, 
	\code{0} for \code{x=a}, and \code{-1} for \code{x<a}.
	\cr
	The delta function \code{Delta} is defined as: 
	\code{Delta(x) = d/dx H(x-a)}.
	\cr
	The boxcar function \code{boxcar} is defined as: 
	\code{Boxcar(x) = H(x+a) - H(x-a)}.
	\cr
	The ramp function is defined as: 
	\code{Ramp(x)= (x-a)*H(x-a)}.
	
}


\value{

	returns the function values of the selected function.
	
}


\references{

Weisstein W. (2004);
	\emph{http://mathworld.wolfram.com/HeavisideStepFunction.html}.
	Mathworld.
	
}


\author{

    Diethelm Wuertz for this \R-port.
    
}

\examples{
## H -
   x = sort(round(c(-1, -0.5, 0, 0.5, 1, 5*rnorm(5)), 2))
   h = H(x)
	
## Sign -
   s = Sign(x)
   
## Delta -
   d = Delta(x)
   
## Boxcar -
   Pi = Boxcar(x)

## ramp - 
   r = Ramp(x)
   cbind(x = x, Step = h, Signum = s, Delta = d, Pi = Pi, R = r)		
}


\keyword{programming}


\eof
\name{snormDistribution}

\alias{snormDistribution}

\alias{dsnorm}
\alias{psnorm}
\alias{qsnorm}
\alias{rsnorm}


\title{Skew Normal Distribution}


\description{
    
    A collection of functions to compute density, distribution function, 
    quantile function and to generate random variates for the skew
    normal distribution. 
    \cr
    
    The functions are:
    
    \tabular{rll}{
        1   \tab    \code{[dpqr]norm}   
            \tab    Normal distribution from R's base package, \cr
        2   \tab    \code{[dpqr]snorm}  
            \tab    Skew Normal distribution.}
}


\usage{
dsnorm(x, mean = 0, sd = 1, xi = 1.5)
psnorm(q, mean = 0, sd = 1, xi = 1.5)
qsnorm(p, mean = 0, sd = 1, xi = 1.5)
rsnorm(n, mean = 0, sd = 1, xi = 1.5)
}


\arguments{

    \item{mean, sd, xi}{
        location parameter \code{mean},
        scale parameter \code{sd},
        skewness parameter \code{xi}.
        }
    \item{n}{
        number of observations.
        } 
    \item{p}{
        a numeric vector of probabilities.
        }
    \item{x, q}{
        a numeric vector of quantiles.
        }
    
}


\value{

    All values are numeric vectors:
    \code{d*} returns the density,
    \code{p*} returns the distribution function,
    \code{q*} returns the quantile function, and
    \code{r*} generates random deviates.
    
}

\details{
  
    \bold{Symmetric Normal Distibution:}
    \cr\cr
    The functions for the normal distribution are part of R's
    base package.
    \cr
    
    \bold{Skew Normal Distribution:}
    \cr\cr
    The skew normal distribution functions are defined as described
    by Fernandez and Steel (2000).
    
}


\examples{
## snorm -
   xmpSeries("\nStart: Skew Normal Distribuion:  > ")
   par(mfrow = c(2, 2), cex = 0.75)
   set.seed(1953)
   r = rsnorm(n = 1000, mean = 1, sd = 0.5, xi = 1.5)
   plot(r, type = "l", main = "snorm: xi = 1.5")
   # Plot empirical density and compare with true density:
   hist(r, n = 25, probability = TRUE, border = "white", col = "steelblue4")
   x = seq(-4, 6, 0.1)
   lines(x, dsnorm(x = x, mean = 1, sd = 0.5, xi = 1.5))
   # Plot df and compare with true df:
   plot(sort(r), (1:1000/1000), main = "Probability", col = "steelblue4")
   lines(x, psnorm(x, mean = 1, sd = 0.5, xi = 1.5))
   # Compute quantiles:
   qsnorm(psnorm(q = -4:6, mean = 1, sd = 0.5, xi = 1.5), 
     mean = 1, sd = 0.5, xi = 1.5) 
}


\author{

    Diethelm Wuertz for this \R-port.
    
}


\references{
Fernandez C., Steel M.F.J. (2000); 
    \emph{On Bayesian Modelling of Fat Tails and Skewness},
    Preprint, 31 pages. 
}


\seealso{
  
    \code{sstdDistribution},
    \code{sgedDistribution}.
    
}


\keyword{distribution}


\eof
\name{sstdDistribution}

\alias{sstdDistribution}

\alias{dstd}
\alias{pstd}
\alias{qstd}
\alias{rstd}

\alias{dsstd}
\alias{psstd}
\alias{qsstd}
\alias{rsstd}


\title{Symmetric and Skew Student-t Distribution}


\description{
    
    A collection of functions to compute density, distribution function, 
    quantile function and to generate random variates for the symmetric
    and skew Sudent-t distribution with unit variance. 
    \cr
    
    The functions are:
    
    \tabular{rll}{
        1   \tab    \code{[dpqr]std}   
            \tab    Symmetric Student-t Distribution, \cr
        2   \tab    \code{[dpqr]sstd}  
            \tab    Skew Student-t Distribution.}
}


\usage{
dstd(x, mean = 0, sd = 1, nu = 5)
pstd(q, mean = 0, sd = 1, nu = 5)
qstd(p, mean = 0, sd = 1, nu = 5)
rstd(n, mean = 0, sd = 1, nu = 5)

dsstd(x, mean = 0, sd = 1, nu = 5, xi = 1.5)
psstd(q, mean = 0, sd = 1, nu = 5, xi = 1.5)
qsstd(p, mean = 0, sd = 1, nu = 5, xi = 1.5)
rsstd(n, mean = 0, sd = 1, nu = 5, xi = 1.5)
}


\arguments{

    \item{mean, sd, nu, xi}{
        location parameter \code{mean},
        scale parameter \code{sd},
        shape parameter \code{nu},
        skewness parameter \code{xi}.
        }
    \item{n}{
        number of observations.
        } 
    \item{p}{
        a numeric vector of probabilities.
        }
    \item{x, q}{
        a numeric vector of quantiles.
        }
    
}


\value{

    All values are numeric vectors:
    \code{d*} returns the density,
    \code{p*} returns the distribution function,
    \code{q*} returns the quantile function, and
    \code{r*} generates random deviates.
    
}

\details{
  
    \bold{Symmetric Student-t Distibution:}
    \cr\cr
    The functions for the symmetric Student-t distribution are 
    rescaled in such a way that they have unit variance in 
    contrast to the Student-t family \code{dt}, \code{pt}, 
    \code{qt} and \code{rt} which are part of R's base package.
    \cr
    
    \bold{Skew Student-t Distribution:}
    \cr\cr
    The skew Student-t distribution functions are defined as described
    by Fernandez and Steel (2000). Note that the function have unit
    variance.
    
}


\examples{
## sstd -
   xmpSeries("\nStart: Skew Student-t Distribuion:  > ")
   par(mfrow = c(2, 2), cex = 0.75)
   set.seed(1953)
   r = rsstd(n = 1000, nu =4, xi = 1.5)
   # Print Variance:
   var(r)
   plot(r, type = "l", main = "sstd: xi = 1.5")
   # Plot empirical density and compare with true density:
   hist(r, n = 30, xlim = c(-5, 5), probability = TRUE, 
     border = "white", col = "steelblue4")
   x = seq(-5, 5, 0.1)
   lines(x, dsnorm(x = x, xi = 1.5))
   # Plot df and compare with true df:
   plot(sort(r), (1:1000/1000), main = "Probability", col = "steelblue4")
   lines(x, psstd(x, xi = 1.5))
   # Compute quantiles:
   qsstd(psstd(q = -5:5, xi = 1.5), xi = 1.5) 
}


\author{

    Diethelm Wuertz for this \R-port.
    
}


\references{
Fernandez C., Steel M.F.J. (2000); 
    \emph{On Bayesian Modelling of Fat Tails and Skewness},
    Preprint, 31 pages. 
}


\seealso{
  
    \code{snormDistribution},
    \code{sgedDistribution}.
    
}


\keyword{distribution}


\eof
\name{sgedDistribution}

\alias{sgedDistribution}

\alias{dged}
\alias{pged}
\alias{qged}
\alias{rged}

\alias{dsged}
\alias{psged}
\alias{qsged}
\alias{rsged}

\title{Symmetric and Skew Generalized Error Distribution}


\description{
    
    A collection of functions to compute density, distribution function, 
    quantile function and to generate random variates for the symmetric
    and skew generalized error distribution. 
    \cr
    
    The functions are:
    
    \tabular{rll}{
        1   \tab    \code{[dpqr]ged}    
            \tab    Symmetric GED distribution, \cr
        2   \tab    \code{[dpqr]sged}   
            \tab    Skew GED distribution.}
}


\usage{
dged(x, mean = 0, sd = 1, nu = 2)
pged(q, mean = 0, sd = 1, nu = 2)
qged(p, mean = 0, sd = 1, nu = 2)
rged(n, mean = 0, sd = 1, nu = 2)

dsged(x, mean = 0, sd = 1, nu = 2, xi = 1.5)
psged(q, mean = 0, sd = 1, nu = 2, xi = 1.5)
qsged(p, mean = 0, sd = 1, nu = 2, xi = 1.5)
rsged(n, mean = 0, sd = 1, nu = 2, xi = 1.5)
}


\arguments{

    \item{mean, sd, nu, xi}{
        location parameter \code{mean},
        scale parameter \code{sd},
        shape parameter \code{nu}, 
        skewness parameter \code{xi}.
        }
    \item{n}{
        number of observations.
        } 
    \item{p}{
        a numeric vector of probabilities.
        }
    \item{x, q}{
        a numeric vector of quantiles.
        }
    
}


\value{

    All values are numeric vectors:
    \code{d*} returns the density,
    \code{p*} returns the distribution function,
    \code{q*} returns the quantile function, and
    \code{r*} generates random deviates.
    
}

\details{
  
    \bold{Symmetric GED Distibution:}
    \cr\cr
    The generalized error distribution functions are defined as 
    described by Nelson (1991).
    \cr
    
    \bold{Skewed GED Distribution:}
    \cr\cr
    The skew generalized error distribution functions are defined as 
    described by Fernandez and Steel (2000).
    
}


\examples{
## sged -
   xmpSeries("\nStart: Skew Generalized Error Distribuion:  > ")
   par(mfrow = c(2, 2), cex = 0.75)
   set.seed(1953)
   r = rsged(n = 1000, mean = 1, sd = 0.5, xi = 1.5)
   plot(r, type = "l", main = "sged: xi = 1.5")
   # Plot empirical density and compare with true density:
   hist(r, n = 25, probability = TRUE, border = "white", col = "steelblue4")
   x = seq(-1, 5, 0.1)
   lines(x, dsged(x = x, mean = 1, sd = 0.5, xi = 1.5))
   # Plot df and compare with true df:
   plot(sort(r), (1:1000/1000), main = "Probability", col = "steelblue4")
   lines(x, psged(x, mean = 1, sd = 0.5, xi = 1.5))
   # Compute quantiles:
   qsged(psged(q = -1:5, mean = 1, sd = 0.5, xi = 1.5), 
     mean = 1, sd = 0.5, xi = 1.5) 
}


\author{

    Diethelm Wuertz for this \R-port.
    
}


\references{

Nelson D.B. (1991);
    \emph{Conditional Heteroscedasticity in Asset Returns: A New Approach},
    Econometrica, 59, 347--370.
    
Fernandez C., Steel M.F.J. (2000); 
    \emph{On Bayesian Modelling of Fat Tails and Skewness},
    Preprint, 31 pages. 
}


\seealso{
  
    \code{sstdDisytribution},
    \code{snormDistribution}.
    
}


\keyword{distribution}


\eof
\name{garchdistFits}

\alias{garchdistFits}

\alias{normFit}
\alias{snormFit}
\alias{stdFit}
\alias{sstdFit}
\alias{gedFit}
\alias{sgedFit}

\title{Parameter Fit of a Distribution}


\description{

	A collection of maximum likelihood estimators to fit the 
	parameters of a distribution and to compute basic statistical
	properties. Included are estimators for the symmetric and skew
	normal, the Student-t, and the generalized error distributions. 
	\cr

	The functions are:
	
	\tabular{rll}{
		1 	\tab 	\code{normFit}   	
			\tab 	MLE parameter fit for a Normal distribution, \cr
		2 	\tab 	\code{snormFit}   	
			\tab 	MLE parameter fit for a skew Normal distribution, \cr
		3 	\tab	\code{stdFit} 	
			\tab 	MLE parameter fit for a Sudent-t distribution, \cr
		4 	\tab	\code{stdFit} 	
			\tab 	MLE parameter fit for a skew Sudent-t distribution, \cr
		5 	\tab	\code{gedFit}	
			\tab 	MLE parameter fit for a generalized error distribution, \cr
		6 	\tab 	\code{nigFit} 	
			\tab 	MLE parameter fit for a skew generalized error distribution. }

}


\usage{
normFit(x, \dots)
snormFit(x, \dots)
stdFit(x, \dots)
sstdFit(x, \dots)
gedFit(x, \dots)
sgedFit(x, \dots)
}


\arguments{
  
	\item{x}{
		a numeric vector.
		}
	\item{\dots}{
		parameters parsed to the optimization function \code{nlm}.
		}

}


\value{
  
  	The functions \code{*Fit} return a list with the following components:
  
  	\item{estimate}{
		the point at which the maximum value of the log liklihood 
		function is obtained.
		}
  	\item{objective}{
		the value of the estimated maximum, i.e. the value of the
		log liklihood function.
		}
  	\item{message}{
		an integer indicating why the optimization process terminated.
		}
  	\item{code}{
		an integer indicating why the optimization process terminated.\cr
		1: relative gradient is close to zero, current iterate is probably 
			solution; \cr
		2: successive iterates within tolerance, current iterate is probably 
			solution; \cr
		3: last global step failed to locate a point lower than \code{estimate}. 
			Either \code{estimate} is an approximate local minimum of the 
			function or \code{steptol} is too small; \cr
 		4: iteration limit exceeded; \cr
 		5: maximum step size \code{stepmax} exceeded five consecutive times. 
 			Either the function is unbounded below, becomes asymptotic to a 
 			finite value from above in some direction or \code{stepmax} 
			is too small.
			}
  	\item{gradient}{
		the gradient at the estimated maximum.
		}
  	\item{steps}{
		number of function calls.
		}
  
}


\details{

	The function \code{\link{nlm}} is used to minimize the "negative" maximum 
	log-likelihood function. \code{nlm} carries out a minimization using 
	a Newton-type algorithm.
	
}


\examples{
## snormFit -
   xmpSeries("\nStart: MLE Fit to skew Normal Density > ")
   options(warn = -1) # suppress negative logs from nlm
   normFit(rnorm(1000))
   snormFit(rnorm(1000))
   
## sstdFit -
   xmpSeries("\nNext: MLE Fit to skew Student-t Density > ")
   sstdFit(rsstd(1000, mean = 1, sd = 1.5, nu = 7, xi = 2/3))
   
## sgedFit -
   xmpSeries("\nNext: MLE Fit to skew Generalized Error Density > ")
   sgedFit(rsged(1000, mean = -1, sd = 0.5, nu = 3, xi = 3/2),
   	 print.level = 2)
}


\seealso{
  
	\code{\link{dsnorm}},
  	\code{\link{dsstd}}, 
  	\code{\link{dsged}}, 
  	\code{\link{nlm}}.
  	
}


\author{

	Diethelm Wuertz for this \R-port.
	
}


\keyword{distribution}


\eof
\name{fSeriesTools}


\alias{fSeriesTools}

\alias{xmpSeries}
\alias{xmpfSeries}


\title{fSeries Tools}


\description{

	Popups the example menu and starts or continues the example 
	and demo programs.
	
}


\usage{
xmpfSeries()
xmpSeries(prompt = "")
}


\arguments{

  	\item{prompt}{
		the string printed when prompting the user for input. 
		}	
}


\value{
  
	xmpfSeries
	\cr
	Popups the example menu.
	\cr
	
	xmpSeries
	\cr
	Nothing, the default, or the the prompt if you have set
	\code{xmpSeries = readline} on the command prompt. 
	
}


\details{

	The example in the manual pages may be interactive and ask for
	input from the user. To achieve this you have to type on the
	command line: \code{xmpSeries = readline}

}


\author{

	Diethelm Wuertz for this R-Port.

}


\examples{
## currently none ...
}


\keyword{programming}


\eof
